pub fn on_access_click(
child: impl IntoUiNode,
handler: Box<dyn FnMut(&AccessClickArgs) -> HandlerResult + Send>,
) -> UiNodeExpand description
Access requested a click.
Note that the normal click event is already triggered by this event.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.