on_access_expander

Function on_access_expander 

pub fn on_access_expander(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&AccessExpanderArgs) -> HandlerResult + Send>,
) -> UiNode
Access requested to expand or collapse the widget content.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.