on_access_increment

Function on_access_increment 

pub fn on_access_increment(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&AccessIncrementArgs) -> HandlerResult + Send>,
) -> UiNode
Access requested to increment or decrement the widget value by steps.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.