on_access_selection

Function on_access_selection 

pub fn on_access_selection(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&AccessSelectionArgs) -> HandlerResult + Send>,
) -> UiNode
Access requested a text selection.

Note that the text widget already handles this event.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.