on_pre_access_number

Function on_pre_access_number 

pub fn on_pre_access_number(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&AccessNumberArgs) -> HandlerResult + Send>,
) -> UiNode
Access requested a number input.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.