on_pre_access_tooltip

Function on_pre_access_tooltip 

pub fn on_pre_access_tooltip(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&AccessToolTipArgs) -> HandlerResult + Send>,
) -> UiNode
Access requested to show or hide the widget’s tooltip.

Note that the tooltip property already handles this event.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.