pub struct AccessClickArgs {
pub timestamp: DInstant,
pub target: WidgetPath,
pub is_primary: bool,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the ACCESS_CLICK_EVENT.
Fields
timestamp: DInstantInstant the event happened.
target: WidgetPathTarget.
is_primary: boolIs primary click (default action).
If false is context click.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl AccessClickArgs
impl AccessClickArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
target: impl Into<WidgetPath>,
is_primary: impl Into<bool>,
) -> AccessClickArgs
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, target: impl Into<WidgetPath>, is_primary: impl Into<bool>, ) -> AccessClickArgs
New args from values that convert into the argument types.
Sourcepub fn now(
target: impl Into<WidgetPath>,
is_primary: impl Into<bool>,
) -> AccessClickArgs
pub fn now( target: impl Into<WidgetPath>, is_primary: impl Into<bool>, ) -> AccessClickArgs
Arguments for event that happened now (INSTANT.now).
Sourceimpl AccessClickArgs
impl AccessClickArgs
Sourcepub fn is_context(&self) -> bool
pub fn is_context(&self) -> bool
Is context click.