pub struct AccessIncrementArgs {
pub timestamp: DInstant,
pub target: WidgetPath,
pub delta: i32,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the ACCESS_INCREMENT_EVENT.
Fields
timestamp: DInstantInstant the event happened.
target: WidgetPathTarget.
delta: i32Increment steps.
Usually is -1 or 1.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl AccessIncrementArgs
impl AccessIncrementArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
target: impl Into<WidgetPath>,
delta: impl Into<i32>,
) -> AccessIncrementArgs
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, target: impl Into<WidgetPath>, delta: impl Into<i32>, ) -> AccessIncrementArgs
New args from values that convert into the argument types.
Sourcepub fn now(
target: impl Into<WidgetPath>,
delta: impl Into<i32>,
) -> AccessIncrementArgs
pub fn now( target: impl Into<WidgetPath>, delta: impl Into<i32>, ) -> AccessIncrementArgs
Arguments for event that happened now (INSTANT.now).