#[non_exhaustive]pub struct CrashError {
pub timestamp: SystemTime,
pub code: Option<i32>,
pub signal: Option<i32>,
pub stdout: Txt,
pub stderr: Txt,
pub args: Box<[Txt]>,
pub minidump: Option<PathBuf>,
pub os: Txt,
}Expand description
Info about an app-process crash.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.timestamp: SystemTimeCrash moment.
code: Option<i32>Process exit code.
signal: Option<i32>Unix signal that terminated the process.
stdout: TxtFull capture of the app stdout.
stderr: TxtFull capture of the app stderr.
args: Box<[Txt]>Arguments used.
minidump: Option<PathBuf>Minidump file.
os: TxtOperating system.
See std::env::consts::OS for details.
Implementations
Sourceimpl CrashError
impl CrashError
Sourcepub fn is_stdout_plain(&self) -> bool
pub fn is_stdout_plain(&self) -> bool
Gets if stdout does not contain any ANSI scape sequences.
Sourcepub fn is_stderr_plain(&self) -> bool
pub fn is_stderr_plain(&self) -> bool
Gets if stderr does not contain any ANSI scape sequences.
Sourcepub fn stdout_plain(&self) -> Txt
pub fn stdout_plain(&self) -> Txt
Get stdout without any ANSI escape sequences (CSI).
Sourcepub fn stderr_plain(&self) -> Txt
pub fn stderr_plain(&self) -> Txt
Get stderr without any ANSI escape sequences (CSI).
Sourcepub fn has_panic_widget(&self) -> bool
pub fn has_panic_widget(&self) -> bool
Gets if stderr contains a crash panic that traced widget/window path.
Sourcepub fn find_panic(&self) -> Option<CrashPanic>
pub fn find_panic(&self) -> Option<CrashPanic>
Try parse stderr for the crash panic.
Only reliably works if the panic fully printed correctly and was formatted by the panic
hook installed by crash_handler or by the display print of CrashPanic.