pub fn can_open(child: impl IntoUiNode, enabled: impl IntoVar<bool>) -> UiNodeExpand description
Defines if
on_open
and
on_pre_open
command handlers are enabled in the widget and descendants.
Sets the CAN_OPEN_VAR.
pub fn can_open(child: impl IntoUiNode, enabled: impl IntoVar<bool>) -> UiNodeDefines if
on_open
and
on_pre_open
command handlers are enabled in the widget and descendants.
Sets the CAN_OPEN_VAR.