pub fn can_save_as(
child: impl IntoUiNode,
enabled: impl IntoVar<bool>,
) -> UiNodeExpand description
Defines if
on_save_as
and
on_pre_save_as
command handlers are enabled in the widget and descendants.
Sets the CAN_SAVE_AS_VAR.
pub fn can_save_as(
child: impl IntoUiNode,
enabled: impl IntoVar<bool>,
) -> UiNodeDefines if
on_save_as
and
on_pre_save_as
command handlers are enabled in the widget and descendants.
Sets the CAN_SAVE_AS_VAR.