pub struct InputDevicesChangedArgs {
pub timestamp: DInstant,
pub devices: HashMap<InputDeviceId, InputDeviceInfo>,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for INPUT_DEVICES_CHANGED_EVENT.
Fields
timestamp: DInstantInstant the event happened.
devices: HashMap<InputDeviceId, InputDeviceInfo>New list of available devices.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl InputDevicesChangedArgs
impl InputDevicesChangedArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
devices: impl Into<HashMap<InputDeviceId, InputDeviceInfo>>,
) -> InputDevicesChangedArgs
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, devices: impl Into<HashMap<InputDeviceId, InputDeviceInfo>>, ) -> InputDevicesChangedArgs
New args from values that convert into the argument types.
Sourcepub fn now(
devices: impl Into<HashMap<InputDeviceId, InputDeviceInfo>>,
) -> InputDevicesChangedArgs
pub fn now( devices: impl Into<HashMap<InputDeviceId, InputDeviceInfo>>, ) -> InputDevicesChangedArgs
Arguments for event that happened now (INSTANT.now).