pub struct AppBuilder { /* private fields */ }Expand description
Application builder.
You can use APP to start building the app.
Implementations
Sourceimpl AppBuilder
impl AppBuilder
Sourcepub fn view_process_exe(
self,
view_process_exe: impl Into<PathBuf>,
) -> AppBuilder
pub fn view_process_exe( self, view_process_exe: impl Into<PathBuf>, ) -> AppBuilder
Set the path to the executable for the View Process.
By the default the current executable is started again as a View Process, you can use two executables instead, by setting this value.
Note that the view_process_exe must start a view server and both
executables must be build using the same exact VERSION.
Sourcepub fn view_process_env(
self,
name: impl Into<Txt>,
value: impl Into<Txt>,
) -> AppBuilder
pub fn view_process_env( self, name: impl Into<Txt>, value: impl Into<Txt>, ) -> AppBuilder
Set an env variable for the view-process.
Sourcepub fn run<F>(self, start: impl IntoFuture<IntoFuture = F>)
pub fn run<F>(self, start: impl IntoFuture<IntoFuture = F>)
Starts the app, then starts polling start to run.
This method only returns when the app has exited.
The start task runs in the app context, note that the future only needs to start the app, usually
by opening a window, the app will keep running after start is finished.
Sourcepub fn run_headless(self, with_renderer: bool) -> HeadlessApp
pub fn run_headless(self, with_renderer: bool) -> HeadlessApp
Initializes extensions in headless mode and returns an HeadlessApp.
If with_renderer is true spawns a renderer process for headless rendering. See HeadlessApp::renderer_enabled
for more details.