pub struct ExitRequestedArgs {
pub timestamp: DInstant,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for EXIT_REQUESTED_EVENT.
Requesting propagation().stop() on this event cancels the exit.
Fields
timestamp: DInstantInstant the event happened.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl ExitRequestedArgs
impl ExitRequestedArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
) -> ExitRequestedArgs
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, ) -> ExitRequestedArgs
New args from values that convert into the argument types.
Sourcepub fn now() -> ExitRequestedArgs
pub fn now() -> ExitRequestedArgs
Arguments for event that happened now (INSTANT.now).