pub struct RwLockWriteGuardOwned<T>where
T: 'static,{ /* private fields */ }Expand description
Represents a read guard for an Arc<RwLock<T>> that owns a reference to it.
Implementations
Sourceimpl<T> RwLockWriteGuardOwned<T>
impl<T> RwLockWriteGuardOwned<T>
Sourcepub fn lock(own: Arc<RwLock<RawRwLock, T>>) -> RwLockWriteGuardOwned<T>
pub fn lock(own: Arc<RwLock<RawRwLock, T>>) -> RwLockWriteGuardOwned<T>
Lock owned.
See parking_lot::RwLock::write for more details.
Sourcepub fn try_lock(
own: Arc<RwLock<RawRwLock, T>>,
) -> Option<RwLockWriteGuardOwned<T>>
pub fn try_lock( own: Arc<RwLock<RawRwLock, T>>, ) -> Option<RwLockWriteGuardOwned<T>>
Lock owned.
See parking_lot::RwLock::try_write for more details.
Sourcepub fn map<O>(
guard: RwLockWriteGuardOwned<T>,
map: impl FnOnce(&mut T) -> &mut O,
) -> MappedRwLockWriteGuardOwned<T, O>
pub fn map<O>( guard: RwLockWriteGuardOwned<T>, map: impl FnOnce(&mut T) -> &mut O, ) -> MappedRwLockWriteGuardOwned<T, O>
Make a new MappedRwLockReadGuardOwned for a component of the locked data.
This is an associated function that needs to be
used as MappedRwLockReadGuardOwned::map(...). A method would interfere with methods of
the same name on the contents of the locked data.