#[non_exhaustive]pub enum AudioSource {
Read(PathBuf),
Download(Uri, Option<Txt>),
Data(AudioHash, IpcBytes, AudioDataFormat),
Audio(Var<AudioTrack>),
}Expand description
The different sources of an audio resource.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Read(PathBuf)
A path to an audio file in the file system.
Audio equality is defined by the path, a copy of the audio in another path is a different audio.
Download(Uri, Option<Txt>)
A uri to an audio resource downloaded using HTTP GET with an optional HTTP ACCEPT string.
If the ACCEPT line is not given, all audio formats supported by the view-process backend are accepted.
Audio equality is defined by the URI and ACCEPT string.
Data(AudioHash, IpcBytes, AudioDataFormat)
Shared reference to bytes for an encoded or decoded audio.
Audio equality is defined by the hash, it is usually the hash of the bytes but it does not need to be.
Inside AUDIOS the reference to the bytes is held only until the audio finishes decoding.
Audio(Var<AudioTrack>)
Already resolved (loaded or loading) audio.
The audio is passed-through, not cached.
Implementations
Sourceimpl AudioSource
impl AudioSource
Sourcepub fn from_data(data: IpcBytes, format: AudioDataFormat) -> AudioSource
pub fn from_data(data: IpcBytes, format: AudioDataFormat) -> AudioSource
New source from data.
Sourcepub fn hash128(&self, options: &AudioOptions) -> Option<AudioHash>
pub fn hash128(&self, options: &AudioOptions) -> Option<AudioHash>
Returns the audio hash, unless the source is AudioTrack.
Sourcepub fn hash128_data(data_hash: AudioHash, options: &AudioOptions) -> AudioHash
pub fn hash128_data(data_hash: AudioHash, options: &AudioOptions) -> AudioHash
Compute hash for a borrowed Data audio.
Sourcepub fn hash128_read(path: &Path, options: &AudioOptions) -> AudioHash
pub fn hash128_read(path: &Path, options: &AudioOptions) -> AudioHash
Compute hash for a borrowed Read path.
Sourcepub fn hash128_download(
uri: &Uri,
accept: &Option<Txt>,
options: &AudioOptions,
) -> AudioHash
pub fn hash128_download( uri: &Uri, accept: &Option<Txt>, options: &AudioOptions, ) -> AudioHash
Compute hash for a borrowed Download URI and HTTP-ACCEPT.