#[non_exhaustive]pub struct AudioFormat {
pub display_name: Txt,
pub media_type_suffixes: Txt,
pub file_extensions: Txt,
pub capabilities: AudioFormatCapability,
}Expand description
Represents an audio codec capability.
This type will be used in the next breaking release of the view API.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.display_name: TxtDisplay name of the format.
media_type_suffixes: TxtMedia types (MIME) associated with the format.
Lowercase, without "audio/" prefix, comma separated if there is more than one.
file_extensions: TxtCommon file extensions associated with the format.
Lowercase, without dot, comma separated if there is more than one.
capabilities: AudioFormatCapabilityCapabilities of this format.
Implementations
Sourceimpl AudioFormat
impl AudioFormat
Sourcepub const fn from_static(
display_name: &'static str,
media_type_suffixes: &'static str,
file_extensions: &'static str,
capabilities: AudioFormatCapability,
) -> AudioFormat
pub const fn from_static( display_name: &'static str, media_type_suffixes: &'static str, file_extensions: &'static str, capabilities: AudioFormatCapability, ) -> AudioFormat
Sourcepub fn media_type_suffixes_iter(&self) -> impl Iterator<Item = &str>
pub fn media_type_suffixes_iter(&self) -> impl Iterator<Item = &str>
Iterate over media type suffixes.
Sourcepub fn media_types(&self) -> impl Iterator<Item = Txt>
pub fn media_types(&self) -> impl Iterator<Item = Txt>
Iterate over full media types, with "image/" prefix.
Sourcepub fn file_extensions_iter(&self) -> impl Iterator<Item = &str>
pub fn file_extensions_iter(&self) -> impl Iterator<Item = &str>
Iterate over extensions.