AudioTrack

Struct AudioTrack 

pub struct AudioTrack { /* private fields */ }
State of an AudioVar.

Implementations

Source

impl AudioTrack

pub fn new_loading() -> AudioTrack

Create a dummy audio in the loading state.

This is the same as calling new_error with an empty error.

pub fn new_error(error: Txt) -> AudioTrack

Create a dummy audio in the error state.

If the error is empty the audio is loading, not an error.

pub fn is_loading(&self) -> bool

Returns true if the is still acquiring or decoding the audio bytes.

pub fn is_loaded(&self) -> bool

If the audio has finished loading ok or due to error.

Note that depending on how the audio is requested and its source it may never be fully loaded.

pub fn can_cue(&self) -> bool

If this audio can be cued for playback already.

This is true when the audio has decoded enough that it can begin streaming.

pub fn is_error(&self) -> bool

If the audio failed to load.

pub fn error(&self) -> Option<Txt>

Returns an error message if the audio failed to load.

pub fn total_duration(&self) -> Option<Duration>

Total duration of the track, if it is known.

Note that this value is set as soon as the header finishes decoding, the chunk may not contains the full stream.

pub fn channel_count(&self) -> u16

Number of channels interleaved in the track.

pub fn sample_rate(&self) -> u32

Samples per second.

A sample is a single sequence of channel_count in chunk.

pub fn chunk(&self) -> IpcBytesCast<f32>

Current decoded samples.

Note that depending on how the audio is requested and its source it may never be fully loaded. The chunk_offset defines the position of the chunk in the overall stream.

pub fn chunk_offset(&self) -> usize

Offset of the chunk in the overall stream.

pub fn has_tracks(&self) -> bool

If tracks is not empty.

pub fn tracks(&self) -> Vec<Var<AudioTrack>>

Other audios from the same container that are a child of this audio.

pub fn flat_tracks(&self) -> Var<Vec<(VarEq<AudioTrack>, usize)>>

All other audios from the same container that are a descendant of this audio.

The values are a tuple of each track and the length of descendants tracks that follow it.

The returned variable will update every time any track descendant var updates.

pub fn track_index(&self) -> usize

Sort index of the audio in the list of tracks of the source container.

pub fn view_handle(&self) -> &ViewAudioHandle

Connection to the audio resource in the view-process.

pub fn insert_track(&mut self, track: Var<AudioTrack>)

Insert track in tracks.