pub fn can_cut(child: impl IntoUiNode, enabled: impl IntoVar<bool>) -> UiNodeExpand description
Defines if
on_cut
and
on_pre_cut
command handlers are enabled in the widget and descendants.
Sets the CAN_CUT_VAR.
pub fn can_cut(child: impl IntoUiNode, enabled: impl IntoVar<bool>) -> UiNodeDefines if
on_cut
and
on_pre_cut
command handlers are enabled in the widget and descendants.
Sets the CAN_CUT_VAR.