pub fn can_settings(
child: impl IntoUiNode,
enabled: impl IntoVar<bool>,
) -> UiNodeExpand description
Defines if
on_settings
and
on_pre_settings
command handlers are enabled in the widget and descendants.
Sets the CAN_SETTINGS_VAR.
pub fn can_settings(
child: impl IntoUiNode,
enabled: impl IntoVar<bool>,
) -> UiNodeDefines if
on_settings
and
on_pre_settings
command handlers are enabled in the widget and descendants.
Sets the CAN_SETTINGS_VAR.