on_drag_end

Function on_drag_end 

pub fn on_drag_end(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&DragEndArgs) -> HandlerResult + Send>,
) -> UiNode
P Draggable widget stopped dragging.

This event is always paired with on_drag_start first.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.