on_drag_enter

Function on_drag_enter 

pub fn on_drag_enter(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&DragHoveredArgs) -> HandlerResult + Send>,
) -> UiNode
P Dragging cursor entered the widget area and the widget is enabled.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.