on_pre_drag_hovered

Function on_pre_drag_hovered 

pub fn on_pre_drag_hovered(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&DragHoveredArgs) -> HandlerResult + Send>,
) -> UiNode
P Dragging cursor entered or exited the widget area and the widget is enabled.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.