on_pre_drag_leave

Function on_pre_drag_leave 

pub fn on_pre_drag_leave(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&DragHoveredArgs) -> HandlerResult + Send>,
) -> UiNode
P Dragging cursor exited the widget area and the widget is enabled.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.