on_pre_drag_start

Function on_pre_drag_start 

pub fn on_pre_drag_start(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&DragStartArgs) -> HandlerResult + Send>,
) -> UiNode
P Draggable widget started dragging.

To receive this event in a widget set draggable to true.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.