on_pre_drop

Function on_pre_drop 

pub fn on_pre_drop(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&DropArgs) -> HandlerResult + Send>,
) -> UiNode
P Dragging cursor dropped data in the widget area and the widget is enabled.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.