#[non_exhaustive]pub struct About {
pub pkg_name: Txt,
pub pkg_authors: Box<[Txt]>,
pub version: Version,
pub app_id: Txt,
pub app: Txt,
pub org: Txt,
pub description: Txt,
pub homepage: Txt,
pub license: Txt,
pub has_about: bool,
pub meta: Vec<(Txt, Txt)>,
pub is_test: bool,
}Expand description
Metadata about the app and main crate.
See about for more details.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pkg_name: Txtpackage.name
Cargo crate name for the entry crate.
package.authors
Cargo crate authors for the entry crate.
version: Versionpackage.version
Cargo crate version for the entry crate.
app_id: Txtpackage.metadata.zng.about.app_id
Fully qualified unique name for the application. Is a list of one or more dot-separated identifiers, each identifier starts with letter, identifiers contains only letters, digits and underscore. A reverse DNS name is recommended.
If the metadata is not set an id is derived from "qualifier", org and app values.
app: Txtpackage.metadata.zng.about.app
App display name.
If the metadata is not set the pkg_name is used.
org: Txtpackage.metadata.zng.about.org
Organization display name.
If the metadata is not set the first pkg_authors is used.
description: Txtpackage.description
Short description of the app.
homepage: Txtpackage.homepage
Valid website about the app.
license: Txtpackage.license
License title of the app.
has_about: boolIf package.metadata.zng.about is set on the Cargo.toml manifest.
The presence of this section is used by cargo zng res to find the main
crate if the workspace has multiple bin crates.
meta: Vec<(Txt, Txt)>package.metadata.zng.about.*
Any other unknown string metadata.
is_test: boolIf app was started in a cfg(test) build binary.
Implementations