pub struct ProcessPath { /* private fields */ }Expand description
Identifies the process as component of an app instance.
The path format as string is the "instance_id//process_id/process_id", the instance_id is in in hexadecimal, followed by
the process_ids in decimal, separated by '/'.
Use process_path to get the current process path.
Implementations
Sourceimpl ProcessPath
impl ProcessPath
Sourcepub fn instance_id(&self) -> u64
pub fn instance_id(&self) -> u64
Unique ID of the current app instance.
Sourcepub fn process_ids(&self) -> &[u32]
pub fn process_ids(&self) -> &[u32]
The std::process::id of the process chain, from parent to child.
Sourcepub fn parent(&self) -> Option<ProcessPath>
pub fn parent(&self) -> Option<ProcessPath>
Get the parent process path if has parent.