pub struct AnyEvent(/* private fields */);Expand description
Represents a type erased event variable.
Implementations
Sourceimpl AnyEvent
impl AnyEvent
Sourcepub fn subscribe(&self, op: UpdateOp, widget_id: WidgetId) -> VarHandle
pub fn subscribe(&self, op: UpdateOp, widget_id: WidgetId) -> VarHandle
Subscribe the widget to receive updates when events are relevant to it.
Sourcepub fn var(&self) -> AnyVar
pub fn var(&self) -> AnyVar
Variable that tracks all the args notified in the last update cycle.
Note that the event variable is only cleared when new notifications are requested.
Sourcepub fn hook(
&self,
handler: impl FnMut(&(dyn AnyEventArgs + 'static)) -> bool + Send + 'static,
) -> VarHandle
pub fn hook( &self, handler: impl FnMut(&(dyn AnyEventArgs + 'static)) -> bool + Send + 'static, ) -> VarHandle
Setups a callback for just after the event notifications are listed, the closure runs in the root app context, just like var modify and hook closures.
The closure must return true to be retained and false to be dropped.
Any event notification or var modification done in the handler will apply on the same update that notifies this event.