CommandArgs

Struct CommandArgs 

pub struct CommandArgs {
    pub timestamp: DInstant,
    pub param: Option<CommandParam>,
    pub scope: CommandScope,
    pub target: Option<WidgetPath>,
    pub enabled: bool,
    pub propagation: EventPropagationHandle,
}
Event args for command events.

Fields

timestamp: DInstant

Instant the event happened.

param: Option<CommandParam>

Optional parameter for the command handler.

scope: CommandScope

Scope of command that notified.

target: Option<WidgetPath>

Target widget.

  • If the scope is App this is None.
  • If the scope is Window this is the window root widget, if the window was found.
  • If the scope is Widget this is the widget, if it was found.
enabled: bool

If the command was enabled when the command notified.

If false the command primary action must not run, but a secondary “disabled interaction” that indicates what conditions enable the command is recommended.

Note that this is the Command::is_enabled value, it is true id any handle is enabled, the local handler might still be disabled.

propagation: EventPropagationHandle

Propagation handle associated with this event instance.

Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.

Implementations

Source

impl CommandArgs

pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, param: impl Into<Option<CommandParam>>, scope: impl Into<CommandScope>, target: impl Into<Option<WidgetPath>>, enabled: impl Into<bool>, ) -> CommandArgs

New args from values that convert into the argument types.

Panics

Panics if the arguments are invalid.

pub fn try_new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, param: impl Into<Option<CommandParam>>, scope: impl Into<CommandScope>, target: impl Into<Option<WidgetPath>>, enabled: impl Into<bool>, ) -> Result<CommandArgs, Txt>

New args from values that convert into the argument types.

Returns an error if the constructed arguments are invalid.

pub fn now( param: impl Into<Option<CommandParam>>, scope: impl Into<CommandScope>, target: impl Into<Option<WidgetPath>>, enabled: impl Into<bool>, ) -> CommandArgs

Arguments for event that happened now (INSTANT.now).

Panics

Panics if the arguments are invalid.

pub fn try_now( param: impl Into<Option<CommandParam>>, scope: impl Into<CommandScope>, target: impl Into<Option<WidgetPath>>, enabled: impl Into<bool>, ) -> Result<CommandArgs, Txt>

Arguments for event that happened now (INSTANT.now).

Returns an error if the constructed arguments are invalid.

pub fn validate(&self) -> Result<(), Txt>

Validates if the target matches the scope.

pub fn assert_valid(&self)

Panics if the arguments are invalid.

Source

impl CommandArgs

pub fn param<T>(&self) -> Option<&T>
where T: Any,

Returns a reference to a parameter of T if parameter is set to a value of T.

pub fn enabled_param<T>(&self) -> Option<&T>
where T: Any,

Returns param if is enabled.

pub fn disabled_param<T>(&self) -> Option<&T>
where T: Any,

Returns param if is not enabled.

pub fn scope_matches(&self, direct_only: bool, scope: CommandScope) -> bool

If direct_only is enabled only matches exact command scope matches, otherwise the app scope matches all args, the window scope matches all events for the window or widgets in the window and the widget scope matches the widget and all descendants.