CommandHandle

Struct CommandHandle 

pub struct CommandHandle { /* private fields */ }
A handle to a Command subscription.

Holding the command handle indicates that the command is relevant in the current app state. The handle also needs to be enabled to indicate that the command primary action can be executed.

You can use the Command::subscribe method in a command type to create a handle.

Implementations

Source

impl CommandHandle

pub fn command(&self) -> Option<Command>

The command.

pub fn enabled(&self) -> &Var<bool>

Variable that gets and sets if this specific handle is enabled.

The Command::is_enabled is true if any handle is enabled.

pub fn dummy() -> CommandHandle

New handle not connected to any command.

pub fn is_dummy(&self) -> bool

If the handle is not connected to any command.

pub fn perm(self)

Drop the handle removing its effect.

The command will be stuck indicating that it has handlers and if this handle is enabled, it will continue indicating it is enabled until the app exit.