VarEventNodeBuilder

Struct VarEventNodeBuilder 

pub struct VarEventNodeBuilder<I, F, M> { /* private fields */ }
Helper for declaring event properties from variables.

Implementations

Source

impl<I, T> VarEventNodeBuilder<I, (), ()>
where T: VarValue, I: FnMut() -> Var<T> + Send + 'static,

pub fn new(init_var: I) -> VarEventNodeBuilder<I, (), ()>

Node that calls the handler for var updates.

The init_var is called on init to

Source

impl<T, I, M> VarEventNodeBuilder<I, (), M>
where T: VarValue, I: FnMut() -> Var<T> + Send + 'static,

pub fn filter<FB, F>(self, filter_builder: FB) -> VarEventNodeBuilder<I, FB, M>
where FB: FnMut() -> F + Send + 'static, F: Fn(&T) -> bool + Send + Sync + 'static,

Filter event.

The filter_builder is called on init and on new, it must produce another closure, the filter predicate. The filter_builder runs in the widget context, the filter predicate does not always.

In the variable hook the filter predicate runs in the app context, it is called if the args target the widget, the predicate must use any captured contextual info to filter the args, this is an optimization, it can save a visit to the widget node.

If the update is received the second filter predicate is called again to confirm the update. If it returns true the handler closure is called.

Source

impl<T, I, F> VarEventNodeBuilder<I, F, ()>
where T: VarValue, I: FnMut() -> Var<T> + Send + 'static,

pub fn map_args<M, MA>(self, map_args: M) -> VarEventNodeBuilder<I, F, M>
where M: FnMut(&T) -> MA + Send + 'static, MA: Clone + 'static,

Convert args.

The map_args closure is called in context, just before the handler is called.

Note that if the args is a full EventArgs type it must share the same propagation handle in the preview and normal route properties, if the source type is also a full args just clone the propagation handle, otherwise you must use WIDGET::set_state to communicate between the properties.

Source

impl<T, I, F, FB, MA, M> VarEventNodeBuilder<I, FB, M>
where T: VarValue, I: FnMut() -> Var<T> + Send + 'static, F: Fn(&T) -> bool + Send + Sync + 'static, FB: FnMut() -> F + Send + 'static, MA: Clone + 'static, M: FnMut(&T) -> MA + Send + 'static,

Build with filter and args mapping.

pub fn build<const PRE: bool>( self, child: impl IntoUiNode, handler: Box<dyn FnMut(&MA) -> HandlerResult + Send>, ) -> UiNode

Build node.

If PRE is true the handler is called before the children, preview route.

Source

impl<T, I, F, FB> VarEventNodeBuilder<I, FB, ()>
where T: VarValue, I: FnMut() -> Var<T> + Send + 'static, F: Fn(&T) -> bool + Send + Sync + 'static, FB: FnMut() -> F + Send + 'static,

Build with filter and without args mapping.

pub fn build<const PRE: bool>( self, child: impl IntoUiNode, handler: Box<dyn FnMut(&T) -> HandlerResult + Send>, ) -> UiNode

Build node.

If PRE is true the handler is called before the children, preview route.

Source

impl<T, I> VarEventNodeBuilder<I, (), ()>
where T: VarValue, I: FnMut() -> Var<T> + Send + 'static,

Build without filter and without args mapping.

pub fn build<const PRE: bool>( self, child: impl IntoUiNode, handler: Box<dyn FnMut(&T) -> HandlerResult + Send>, ) -> UiNode

Build node.

If PRE is true the handler is called before the children, preview route.

Source

impl<T, I, MA, M> VarEventNodeBuilder<I, (), M>
where T: VarValue, I: FnMut() -> Var<T> + Send + 'static, MA: Clone + 'static, M: FnMut(&T) -> MA + Send + 'static,

Build with no filter and args mapping.

pub fn build<const PRE: bool>( self, child: impl IntoUiNode, handler: Box<dyn FnMut(&MA) -> HandlerResult + Send>, ) -> UiNode

Build node.

If PRE is true the handler is called before the children, preview route.