FocusClickBehavior

Enum FocusClickBehavior 

pub enum FocusClickBehavior {
    Ignore,
    Exit {
        recursive_alt: bool,
        enabled: bool,
        handled: bool,
    },
}
Behavior of a widget when a click event is send to it or a descendant.

See focus_click_behavior for more details.

Variants



Ignore

Click event always ignored.



Exit

Exit focus if a click event was send to the widget or descendant.

Fields

recursive_alt: bool

If exiting from an ALT scope recursively seek the return widget that is not inside any ALT scope.

enabled: bool

Exit only if click targets an enabled widget.

handled: bool

Exit only if the click event propagation was stopped.

Implementations

Source

impl FocusClickBehavior

pub fn menu_item() -> FocusClickBehavior

Default behavior for menu item buttons.

Only if the item is enabled, exits entire menu.