on_focus

Function on_focus 

pub fn on_focus(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&FocusChangedArgs) -> HandlerResult + Send>,
) -> UiNode
P Widget got direct keyboard focus.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.