pub fn on_focus_changed(
child: impl IntoUiNode,
handler: Box<dyn FnMut(&FocusChangedArgs) -> HandlerResult + Send>,
) -> UiNodeExpand description
P Focus changed in the widget or its descendants.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.