on_pre_focus

Function on_pre_focus 

pub fn on_pre_focus(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&FocusChangedArgs) -> HandlerResult + Send>,
) -> UiNode
P Widget got direct keyboard focus.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.