on_pre_focus_enter

Function on_pre_focus_enter 

pub fn on_pre_focus_enter(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&FocusChangedArgs) -> HandlerResult + Send>,
) -> UiNode
P Widget or one of its descendants got focus.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.