#[non_exhaustive]pub struct FontMetrics {
pub size_scale: f32,
pub ascent: Px,
pub descent: Px,
pub line_gap: Px,
pub underline_position: Px,
pub underline_thickness: Px,
pub cap_height: Px,
pub x_height: Px,
pub bounds: Rect<Px, Px>,
}Expand description
Various metrics about a Font.
You can compute these metrics from a FontFaceMetrics
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.size_scale: f32Multiply this to a font EM value to get the size in pixels.
ascent: PxThe maximum amount the font rises above the baseline, in pixels.
descent: PxThe maximum amount the font descends below the baseline, in pixels.
This is typically a negative value to match the definition of sTypoDescender in the
OS/2 table in the OpenType specification. If you are used to using Windows or Mac APIs,
beware, as the sign is reversed from what those APIs return.
line_gap: PxDistance between baselines, in pixels.
underline_position: PxThe suggested distance of the top of the underline from the baseline (negative values indicate below baseline), in pixels.
underline_thickness: PxA suggested value for the underline thickness, in pixels.
cap_height: PxThe approximate amount that uppercase letters rise above the baseline, in pixels.
x_height: PxThe approximate amount that non-ascending lowercase letters rise above the baseline, in pixels.
bounds: Rect<Px, Px>A rectangle that surrounds all bounding boxes of all glyphs, in pixels.
This corresponds to the xMin/xMax/yMin/yMax values in the OpenType head table.
Implementations
Sourceimpl FontMetrics
impl FontMetrics
Sourcepub fn line_height(&self) -> Px
pub fn line_height(&self) -> Px
The font line height.