pub enum Mnemonic {
Auto,
Char(char),
FromTxt {
marker: char,
fallback_auto: bool,
},
None,
}Expand description
Defines the mnemonic char key that clicks the widget when pressed and focus is within the parent mnemonic scope.
Variants
Auto
Scope selects a char using the inner mnemonic_txt of the widget or descendants.
Char(char)
Explicit alphanumeric char.
The associated char must be a value that can appear in Key::Char (case indifferent), otherwise it will never match.
In case the same key is set for multiple widgets in a scope the first widget (in tab order) takes it, the others do not enable mnemonic shortcut.
FromTxt
Explicit alphanumeric key defined in the widget inner text, identified by a marker prefix.
After the char is extracted this behaves like Char. If the marker is not found also fallback to Auto.
The Label! widget automatically hides the marker (first occurrence before an alphanumeric char).
Fields
None
No mnemonic behavior, disabled.
Implementations