pub fn on_click(
child: impl IntoUiNode,
handler: Box<dyn FnMut(&ClickArgs) -> HandlerResult + Send>,
) -> UiNodeExpand description
P On widget click with the primary button and any click count and the widget is enabled.
This raises only if the click is primary, but raises for any click count (double/triple clicks).
Use on_any_click to handle clicks from any button or on_single_click to not include
double/triple clicks.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.