on_context_click

Function on_context_click 

pub fn on_context_click(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&ClickArgs) -> HandlerResult + Send>,
) -> UiNode
P On widget click with the secondary/context button and the widget is enabled.

This raises only if the click is context.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.