on_disabled_click

Function on_disabled_click 

pub fn on_disabled_click(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&ClickArgs) -> HandlerResult + Send>,
) -> UiNode
P On widget click from any source and of any click count and the widget is disabled.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.