pub fn on_pre_any_click(
child: impl IntoUiNode,
handler: Box<dyn FnMut(&ClickArgs) -> HandlerResult + Send>,
) -> UiNodeExpand description
P On widget click from any source and of any click count and the widget is enabled.
This is the most general click handler, it raises for all possible sources of the CLICK_EVENT and any number
of consecutive clicks. Use on_click to handle only primary button clicks or on_any_single_click
to not include double/triple clicks.
Route
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the
$pn_ident
handlers.