pub fn on_pre_any_double_click(
child: impl IntoUiNode,
handler: Box<dyn FnMut(&ClickArgs) -> HandlerResult + Send>,
) -> UiNodeExpand description
P On widget double click from any source and the widget is enabled.
This raises for all possible sources of CLICK_EVENT, but only when the click count is two. Use
on_double_click to handle only primary button clicks.
Route
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the
$pn_ident
handlers.