on_pre_any_triple_click

Function on_pre_any_triple_click 

pub fn on_pre_any_triple_click(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&ClickArgs) -> HandlerResult + Send>,
) -> UiNode
P On widget triple click from any source and the widget is enabled.

This raises for all possible sources of CLICK_EVENT, but only when the click count is three. Use on_triple_click to handle only primary button clicks.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.