pub fn on_pre_context_click(
child: impl IntoUiNode,
handler: Box<dyn FnMut(&ClickArgs) -> HandlerResult + Send>,
) -> UiNodeExpand description
P On widget click with the secondary/context button and the widget is enabled.
This raises only if the click is context.
Route
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the
$pn_ident
handlers.