on_pre_double_click

Function on_pre_double_click 

pub fn on_pre_double_click(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&ClickArgs) -> HandlerResult + Send>,
) -> UiNode
P On widget double click with the primary button and the widget is enabled.

This raises only if the click is primary and the click count is two. Use on_any_double_click to handle double clicks from any button.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.