pub fn on_pre_triple_click(
child: impl IntoUiNode,
handler: Box<dyn FnMut(&ClickArgs) -> HandlerResult + Send>,
) -> UiNodeExpand description
P On widget triple click with the primary button and the widget is enabled.
This raises only if the click is primary and the click count is three. Use
on_any_double_click to handle double clicks from any button.
Route
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the
$pn_ident
handlers.