on_single_click

Function on_single_click 

pub fn on_single_click(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&ClickArgs) -> HandlerResult + Send>,
) -> UiNode
P On widget click with the primary button, excluding double/triple clicks and the widget is enabled.

This raises only if the click is primary and the click count is one. Use on_any_single_click to handle single clicks from any button.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.