CommandIconExt

Trait CommandIconExt 

pub trait CommandIconExt {
    // Required methods
    fn icon(self) -> Var<WidgetFn<()>>;
    fn init_icon(self, icon: WidgetFn<()>) -> Self;
}
Adds the icon command metadata.

The value is an WidgetFn<()> that can generate any icon widget, the ICONS service is recommended.

Required Methods

fn icon(self) -> Var<WidgetFn<()>>

Gets a read-write variable that is the icon for the command.

fn init_icon(self, icon: WidgetFn<()>) -> Self

Sets the initial icon if it is not set.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors