ImageDownscaleMode

Enum ImageDownscaleMode 

#[non_exhaustive]
pub enum ImageDownscaleMode { Fit(Size2D<Px, Px>), Fill(Size2D<Px, Px>), MipMap { min_size: Size2D<Px, Px>, max_size: Size2D<Px, Px>, }, Entries(Vec<ImageDownscaleMode>), }
Defines how an image is downscaled after decoding.

The image aspect ratio is preserved in all modes. The image is never upscaled. If the image container contains reduced alternative the nearest to the requested size is used as source.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Fit(Size2D<Px, Px>)

Image is downscaled so that both dimensions fit inside the size.



Fill(Size2D<Px, Px>)

Image is downscaled so that at least one dimension fits inside the size. The image is not clipped.



MipMap

Generate synthetic ImageEntryKind::Reduced entries each half the size of the image until the sample that is nearest min_size and greater or equal to it. If the image container already has alternates that are equal to or near a mip size that size is used instead.

Fields

min_size: Size2D<Px, Px>

Minimum sample size.

max_size: Size2D<Px, Px>

Maximum Fill size.



Entries(Vec<ImageDownscaleMode>)

Generate multiple synthetic ImageEntryKind::Reduced entries. The entry sizes are sorted by largest first, if the image full size already fits in the largest downscale requested the full image is returned and any downscale actually smaller becomes a synthetic entry. If the image is larger than all requested sizes it is downscaled as well.

Implementations

Source

impl ImageDownscaleMode

pub fn mip_map() -> ImageDownscaleMode

Default mipmap min/max when the objective of the mipmap is optimizing dynamically resizing massive images.

pub fn with_entry( self, other: impl Into<ImageDownscaleMode>, ) -> ImageDownscaleMode

Append entry downscale request.

pub fn sizes( &self, page_size: Size2D<Px, Px>, reduced_sizes: &[Size2D<Px, Px>], ) -> (Option<Size2D<Px, Px>>, Vec<Size2D<Px, Px>>)

Get downscale sizes that need to be generated.

The page_size is the image full size, the reduced_sizes are sizes of reduced alternates that are already provided by the image container.

Returns the downscale for the image full size, if needed and a list of reduced entries that must be synthesized, sorted largest to smallest.