mask_image_entries_mode

Function mask_image_entries_mode 

pub fn mask_image_entries_mode(
    child: impl IntoUiNode,
    mode: impl IntoVar<ImageEntriesMode>,
) -> UiNode
P Defines what mask images are decoded from multi image containers.

By default container types like TIFF or ICO only decode the first/largest image, this property defines if other contained images are also requested.

If the image contains a Reduced alternate the best size is used during rendering, this is particularly useful for displaying icon files that have symbolic alternates that are more readable at a smaller size.

This property sets the MASK_IMAGE_ENTRIES_MODE_VAR.