mnemonic_underline

Function mnemonic_underline 

pub fn mnemonic_underline(
    child: impl IntoUiNode,
    enabled: impl IntoVar<bool>,
) -> UiNode
P Only draw underline under active mnemonic char in labels.

When enabled this overrides underline_skip in labels, only the char defined by get_mnemonic_char is underlined.

Note that underline must also be set to a visible state in context.