on_link

Function on_link 

pub fn on_link(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&LinkArgs) -> HandlerResult + Send>,
) -> UiNode
P Markdown link click.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.