on_pre_link

Function on_pre_link 

pub fn on_pre_link(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&LinkArgs) -> HandlerResult + Send>,
) -> UiNode
P Markdown link click.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.