pub fn on_disabled_mouse_wheel(
child: impl IntoUiNode,
handler: Box<dyn FnMut(&MouseWheelArgs) -> HandlerResult + Send>,
) -> UiNodeExpand description
P Mouse wheel scrolled while pointer is hovering widget and it is disabled.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.