pub fn on_mouse_any_double_click(
child: impl IntoUiNode,
handler: Box<dyn FnMut(&MouseClickArgs) -> HandlerResult + Send>,
) -> UiNodeExpand description
P Mouse double clicked on the widget with any button and it is enabled.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.