on_mouse_click

Function on_mouse_click 

pub fn on_mouse_click(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&MouseClickArgs) -> HandlerResult + Send>,
) -> UiNode
P Mouse clicked on the widget with the primary button including repeat clicks and it is enabled.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.