on_mouse_double_click

Function on_mouse_double_click 

pub fn on_mouse_double_click(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&MouseClickArgs) -> HandlerResult + Send>,
) -> UiNode
P Mouse double clicked on the widget with the primary button and it is enabled.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.