on_mouse_down

Function on_mouse_down 

pub fn on_mouse_down(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&MouseInputArgs) -> HandlerResult + Send>,
) -> UiNode
P Mouse button pressed while the cursor is over the widget, the widget is enabled and cursor capture allows it.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.