on_mouse_hovered

Function on_mouse_hovered 

pub fn on_mouse_hovered(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&MouseHoverArgs) -> HandlerResult + Send>,
) -> UiNode
P Mouse entered or left the widget and descendant widgets area, the widget is enabled and cursor capture allows it.

You can use the is_mouse_enter and is_mouse_leave methods to determinate the state change.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.