on_mouse_input

Function on_mouse_input 

pub fn on_mouse_input(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&MouseInputArgs) -> HandlerResult + Send>,
) -> UiNode
P Mouse button pressed or released while the cursor is over the widget, the widget is enabled and no cursor capture blocks it.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.