on_mouse_move

Function on_mouse_move 

pub fn on_mouse_move(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&MouseMoveArgs) -> HandlerResult + Send>,
) -> UiNode
P Mouse cursor moved over the widget and cursor capture allows it.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.