on_pre_mouse_click

Function on_pre_mouse_click 

pub fn on_pre_mouse_click(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&MouseClickArgs) -> HandlerResult + Send>,
) -> UiNode
P Mouse clicked on the widget with the primary button including repeat clicks and it is enabled.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.