on_pre_mouse_leave

Function on_pre_mouse_leave 

pub fn on_pre_mouse_leave(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&MouseHoverArgs) -> HandlerResult + Send>,
) -> UiNode
P Mouse is no longer over the widget or any descendant widget, the widget is enabled and cursor capture allows it.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.