pub fn on_pre_mouse_scroll(
child: impl IntoUiNode,
handler: Box<dyn FnMut(&MouseWheelArgs) -> HandlerResult + Send>,
) -> UiNodeExpand description
P Mouse wheel scrolled while pointer is hovering the widget and the pressed keyboard modifiers allow a scroll operation and
the widget is enabled.
Route
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the
$pn_ident
handlers.