on_pre_mouse_zoom

Function on_pre_mouse_zoom 

pub fn on_pre_mouse_zoom(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&MouseWheelArgs) -> HandlerResult + Send>,
) -> UiNode
P Mouse wheel scrolled while pointer is hovering the widget and the pressed keyboard modifiers allow a zoom operation and the widget is enabled.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.