MouseMoveArgs

Struct MouseMoveArgs 

pub struct MouseMoveArgs {
    pub timestamp: DInstant,
    pub window_id: WindowId,
    pub device_id: InputDeviceId,
    pub modifiers: ModifiersState,
    pub coalesced_pos: Vec<Point2D<Dip, Dip>>,
    pub position: Point2D<Dip, Dip>,
    pub hits: HitTestInfo,
    pub target: InteractionPath,
    pub capture: Option<CaptureInfo>,
    pub propagation: EventPropagationHandle,
}
MOUSE_MOVE_EVENT arguments.

Fields

timestamp: DInstant

Instant the event happened.

window_id: WindowId

Id of window that received the event.

device_id: InputDeviceId

Id of device that generated the event.

modifiers: ModifiersState

What modifier keys where pressed when this event happened.

coalesced_pos: Vec<Point2D<Dip, Dip>>

Positions of the cursor in between the previous event and this one.

Mouse move events can be coalesced, i.e. multiple moves packed into a single event.

position: Point2D<Dip, Dip>

Position of the mouse in the window’s content area.

hits: HitTestInfo

Hit-test result for the mouse point in the window.

target: InteractionPath

Full path to the top-most hit in hits.

capture: Option<CaptureInfo>

Current pointer capture.

propagation: EventPropagationHandle

Propagation handle associated with this event instance.

Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.

Implementations

Source

impl MouseMoveArgs

pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, window_id: impl Into<WindowId>, device_id: impl Into<InputDeviceId>, modifiers: impl Into<ModifiersState>, coalesced_pos: impl Into<Vec<Point2D<Dip, Dip>>>, position: impl Into<Point2D<Dip, Dip>>, hits: impl Into<HitTestInfo>, target: impl Into<InteractionPath>, capture: impl Into<Option<CaptureInfo>>, ) -> MouseMoveArgs

New args from values that convert into the argument types.

pub fn now( window_id: impl Into<WindowId>, device_id: impl Into<InputDeviceId>, modifiers: impl Into<ModifiersState>, coalesced_pos: impl Into<Vec<Point2D<Dip, Dip>>>, position: impl Into<Point2D<Dip, Dip>>, hits: impl Into<HitTestInfo>, target: impl Into<InteractionPath>, capture: impl Into<Option<CaptureInfo>>, ) -> MouseMoveArgs

Arguments for event that happened now (INSTANT.now).

Source

impl MouseMoveArgs

pub fn capture_allows(&self, wgt: (WindowId, WidgetId)) -> bool

If capture is None or allows the wgt to receive this event.

pub fn position_wgt(&self, wgt: (WindowId, WidgetId)) -> Option<Point2D<Px, Px>>

Gets position in the widget inner bounds.