on_got_pointer_capture

Function on_got_pointer_capture 

pub fn on_got_pointer_capture(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&PointerCaptureArgs) -> HandlerResult + Send>,
) -> UiNode
P Widget acquired mouse and touch capture.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.