on_pre_popup_close_requested

Function on_pre_popup_close_requested 

pub fn on_pre_popup_close_requested(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&PopupCloseRequestedArgs) -> HandlerResult + Send>,
) -> UiNode
P Closing popup event.

Requesting propagation().stop() on this event cancels the popup close.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.