ScrollUnitsMix

Struct ScrollUnitsMix 

pub struct ScrollUnitsMix<P>(/* private fields */);
m Properties that define scroll units.

Implementations

Source

impl<P> ScrollUnitsMix<P>
where P: WidgetImpl,

pub fn v_line_unit(&self, unit: impl IntoVar<Length>)

P Vertical offset added when the SCROLL_DOWN_CMD runs and removed when the SCROLL_UP_CMD runs.

Relative lengths are relative to the viewport height.

This property sets the VERTICAL_LINE_UNIT_VAR.

Source

impl<P> ScrollUnitsMix<P>
where P: WidgetImpl,

pub fn h_line_unit(&self, unit: impl IntoVar<Length>)

P Horizontal offset added when the SCROLL_RIGHT_CMD runs and removed when the SCROLL_LEFT_CMD runs.

Relative lengths are relative to the viewport width.

This property sets the HORIZONTAL_LINE_UNIT_VAR.

Source

impl<P> ScrollUnitsMix<P>
where P: WidgetImpl,

pub fn line_units( &self, horizontal: impl IntoVar<Length>, vertical: impl IntoVar<Length>, )

P Horizontal and vertical offsets used when scrolling.

This property sets the h_line_unit and v_line_unit.

Source

impl<P> ScrollUnitsMix<P>
where P: WidgetImpl,

pub fn alt_factor(&self, factor: impl IntoVar<Factor>)

P Scroll unit multiplier used when alternate scrolling.

This property sets the ALT_FACTOR_VAR.

Source

impl<P> ScrollUnitsMix<P>
where P: WidgetImpl,

pub fn v_page_unit(&self, unit: impl IntoVar<Length>)

P Vertical offset added when the PAGE_DOWN_CMD runs and removed when the PAGE_UP_CMD runs.

Relative lengths are relative to the viewport height.

This property sets the VERTICAL_PAGE_UNIT_VAR.

Source

impl<P> ScrollUnitsMix<P>
where P: WidgetImpl,

pub fn h_page_unit(&self, unit: impl IntoVar<Length>)

P Horizontal offset added when the PAGE_RIGHT_CMD runs and removed when the PAGE_LEFT_CMD runs.

Relative lengths are relative to the viewport width.

This property sets the HORIZONTAL_PAGE_UNIT_VAR.

Source

impl<P> ScrollUnitsMix<P>
where P: WidgetImpl,

pub fn page_units( &self, horizontal: impl IntoVar<Length>, vertical: impl IntoVar<Length>, )

P Horizontal and vertical offsets used when page-scrolling.

This property sets the h_page_unit and v_page_unit.

Source

impl<P> ScrollUnitsMix<P>
where P: WidgetImpl,

pub fn h_wheel_unit(&self, unit: impl IntoVar<Length>)

P Horizontal offset added when the mouse wheel is scrolling by lines.

The unit value is multiplied by the MouseScrollDelta::LineDelta x value to determinate the scroll delta.

This property sets the HORIZONTAL_WHEEL_UNIT_VAR.

Source

impl<P> ScrollUnitsMix<P>
where P: WidgetImpl,

pub fn v_wheel_unit(&self, unit: impl IntoVar<Length>)

P Vertical offset added when the mouse wheel is scrolling by lines.

The unit value is multiplied by the MouseScrollDelta::LineDelta y value to determinate the scroll delta.

This property sets the VERTICAL_WHEEL_UNIT_VAR`.

Source

impl<P> ScrollUnitsMix<P>
where P: WidgetImpl,

pub fn wheel_units( &self, horizontal: impl IntoVar<Length>, vertical: impl IntoVar<Length>, )

P Horizontal and vertical offsets used when mouse wheel scrolling.

This property sets the h_wheel_unit and v_wheel_unit.

Source

impl<P> ScrollUnitsMix<P>
where P: WidgetImpl,

pub fn zoom_wheel_unit(&self, unit: impl IntoVar<Factor>)

P Scale delta added when the mouse wheel is zooming by lines.

The unit value is multiplied by the MouseScrollDelta::LineDelta value to determinate the scale delta.

This property sets the ZOOM_WHEEL_UNIT_VAR.

Source

impl<P> ScrollUnitsMix<P>
where P: WidgetImpl,

pub fn define_viewport_unit(&self, enabled: impl IntoVar<bool>)

P If the scroll defines its viewport size as the LayoutMetrics::viewport for the scroll content.

This property sets the DEFINE_VIEWPORT_UNIT_VAR.