pub enum SetupErrorState {
Canceled,
PartialPrepareInstall,
PartialInstall {
data: UninstallConfig,
no_data: Vec<(usize, TaskTypeId, Txt)>,
},
PartialUninstall,
}Expand description
Represents state of a setup operation that ended in a SetupError.
Variants
Canceled
Canceled successfully, all changes where reverted.
The operation is canceled by request or by error before it starts committing irreversible changes, either way the system and any previous installation is not affected when ended in this state.
PartialPrepareInstall
Install operation failed before it started making irreversible changes and failed to cleanup temporary changes.
When an install fails during the preparing phase it automatically attempts to cancel, this is the error when that cancel fails. If the install was an update the previous version will still be valid.
PartialInstall
Install operation failed while making irreversible changes to the system.
Operation attempts to complete as much of the install as possible, the associated data
can be used to uninstall the committed changes. Well designed tasks will cleanup all temporary
prepared data on error and generate uninstall data that cleanups even partial written files, but
there is no guarantee that this data will fully uninstall every change.
If the operation was replacing a previous install (update or repair) the data will also
uninstall the previous installation.
Fields
data: UninstallConfigData that can uninstall all the successfully committed changes made during the failed install.
no_data: Vec<(usize, TaskTypeId, Txt)>Tasks that failed without generating uninstall data.
If this is not empty uninstalling data will definitely not fully cleanup the broken install.
Tasks are identified by index on the operation, type and name.
PartialUninstall
Uninstall operation failed while making irreversible changes to the system.
Operation attempts to complete as much of the uninstall as possible, so all tasks without error have completed successfully.