pub struct FailedPage {
pub error: SetupError,
pub task_infos: Vec<TaskInfo>,
pub task_info_fn: WidgetFn<FailedTaskInfoFnArgs>,
}Expand description
Setup operation failed page.
Fields
error: SetupErrorThe error.
task_infos: Vec<TaskInfo>Display info about setup task components of the operation that failed.
This task list is displayed on the same order as defined, as a check list with individual progress indicator.
If this list is empty or a task is not present only the overall operation error is shown.
This is usually a clone of StatusPage::task_infos.
task_info_fn: WidgetFn<FailedTaskInfoFnArgs>Widget that generates the status item for each item in task_infos.
Implementations
Sourceimpl FailedPage
impl FailedPage
Sourcepub fn new(error: SetupError) -> FailedPage
pub fn new(error: SetupError) -> FailedPage
New from error, without task infos.