pub struct InstallConfig { /* private fields */ }Expand description
Represents a list of tasks for a SETUP.install operation.
Implementations
Sourceimpl InstallConfig
impl InstallConfig
Sourcepub fn new() -> InstallConfig
pub fn new() -> InstallConfig
New empty.
Sourcepub fn push<T>(
&mut self,
name: impl Into<Txt>,
config: <T as SetupTask>::InstallConfig,
)where
T: SetupTask,
pub fn push<T>(
&mut self,
name: impl Into<Txt>,
config: <T as SetupTask>::InstallConfig,
)where
T: SetupTask,
Push a task to run.
The name is used to identify the task instance in progress status.
Sourcepub fn tasks(&self) -> &[(TaskTypeId, Txt)]
pub fn tasks(&self) -> &[(TaskTypeId, Txt)]
Task types and names in order they will execute.