#[non_exhaustive]pub struct SetupError {
pub op_error: Option<SetupTaskError>,
pub task_errors: Vec<((usize, TaskTypeId, Txt), SetupTaskError)>,
pub state: SetupErrorState,
}Expand description
Represents a SETUP operation error.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.op_error: Option<SetupTaskError>Error associated with operation itself that affects all tasks.
This is often SetupTaskError::CorruptedTaskData detected
task_errors: Vec<((usize, TaskTypeId, Txt), SetupTaskError)>Errors associated with a task in the operation.
Each task is identified by index on the operation, type and name.
state: SetupErrorStateOperation state after not completing successfully.
Implementations
Sourceimpl SetupError
impl SetupError
Sourcepub fn canceled() -> SetupError
pub fn canceled() -> SetupError
No actual error, canceled by request.
Sourcepub fn task_errors(
errors: Vec<((usize, TaskTypeId, Txt), SetupTaskError)>,
state: SetupErrorState,
) -> SetupError
pub fn task_errors( errors: Vec<((usize, TaskTypeId, Txt), SetupTaskError)>, state: SetupErrorState, ) -> SetupError
One or more tasks failed.
Each task is identified by index on the operation, type and name.
If the tasks managed to reverse all changes before committing the state must be Canceled.
Sourcepub fn op_error(error: SetupTaskError, state: SetupErrorState) -> SetupError
pub fn op_error(error: SetupTaskError, state: SetupErrorState) -> SetupError
Operation failed with error associated with operation itself that affects all tasks.
If the error is detected before any task runs and any non-destructive change was made the state must be Canceled.
Sourcepub fn corrupted_op_config(config_name: &'static str) -> SetupError
pub fn corrupted_op_config(config_name: &'static str) -> SetupError
Operation cannot start due to corrupted config data.