#[non_exhaustive]pub struct SetupOpStatus {
pub cancel: bool,
pub task: (TaskTypeId, Txt),
pub progress: (usize, usize),
pub task_progress: VarEq<Progress>,
pub errors: Vec<((usize, TaskTypeId, Txt), SetupTaskError)>,
}Expand description
Represents status of a SETUP install or uninstall operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cancel: boolIs cancelling.
task: (TaskTypeId, Txt)Current task.
progress: (usize, usize)Task index of len.
task_progress: VarEq<Progress>Progress report from task.
errors: Vec<((usize, TaskTypeId, Txt), SetupTaskError)>Errors.
The task is identified by index, type and name.
Implementations
Sourceimpl SetupOpStatus
impl SetupOpStatus
Sourcepub fn is_complete(&self) -> bool
pub fn is_complete(&self) -> bool
If progress is last task and task_progress is complete.
Note that tasks report completion on error.
Sourcepub fn is_canceled(&self) -> bool
pub fn is_canceled(&self) -> bool
If cancel and is_complete.
If this is true and errors is not empty the tasks managed to cleanup and the install is not corrupted.
Sourcepub fn is_corrupted(&self) -> bool
pub fn is_corrupted(&self) -> bool
If is_complete, not cancel and has errors.
If this is true the tasks did not manage to cleanup and the install is in a corrupted state.