pub struct SfxClient { /* private fields */ }Expand description
Connection with a self-extracting executable generated by cargo zng res --tool sfx.
Implementations
Sourceimpl SfxClient
impl SfxClient
Sourcepub fn connect_blocking() -> Result<SfxClient, SfxError>
pub fn connect_blocking() -> Result<SfxClient, SfxError>
Connect with the “SFX_ARGS” defined server.
Sourcepub async fn connect() -> Result<SfxClient, SfxError>
pub async fn connect() -> Result<SfxClient, SfxError>
Connect with the “SFX_ARGS” defined server.
Sourcepub fn sfx_args(&self) -> &[Txt]
pub fn sfx_args(&self) -> &[Txt]
The command line arguments from the SFX executable.
Note that the sfx process that spawned this process is still running and replicating stdout/err from this process, impersonating the extracted executable.
These args are from the user, the std::env::args are from the sfx tool and are usually empty.
Sourcepub fn manifest(&self) -> &[SfxDataInfo]
pub fn manifest(&self) -> &[SfxDataInfo]
Info an all data the server can provide.
List is sorted by name.
Sourcepub fn info(&self, name: &str) -> Option<&SfxDataInfo>
pub fn info(&self, name: &str) -> Option<&SfxDataInfo>
Get name data info it it is in the server manifest.
Sourcepub fn read_blocking(&self, name: &str) -> Result<SfxReadBlocking, SfxError>
pub fn read_blocking(&self, name: &str) -> Result<SfxReadBlocking, SfxError>
Read raw data.
The sfx server will automatically decompress/decode data that was marked compress on build.