pub enum CopyCurrentExe {}Expand description
Setup task that copies std::env::current_exe to a location.
The current exe is the setup executable, this task is useful when the setup executable is also the app executable, or when it is needed to uninstall.