#[non_exhaustive]pub enum SetupTaskError {
CorruptedTaskData(Arc<dyn Error + Send + Sync>),
UnknownType(TaskTypeId),
Io(Vec<(PathBuf, Arc<Error>)>),
Other(Vec<Arc<dyn Error + Send + Sync>>),
}Expand description
Represents a SetupTask step error.
Some tasks may continue after an error in a best attempt to at least complete most of the work,
this can cause multiple errors to aggregate. In these cases the Error::source is the first
error.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CorruptedTaskData(Arc<dyn Error + Send + Sync>)
Task data is in an unexpected format.
UnknownType(TaskTypeId)
Task type is not registered.
Io(Vec<(PathBuf, Arc<Error>)>)
IO errors associated with a file or directory path.
Other(Vec<Arc<dyn Error + Send + Sync>>)
Other errors.
Implementations