IpcReadHandle

Enum IpcReadHandle 

#[non_exhaustive]
pub enum IpcReadHandle { File(IpcFileHandle), Bytes(IpcBytes), }
File handle or allocated bytes that can be read after sending to another process.

Position

Read always starts from the beginning, the read methods seek the file start before returning. Note that the read position is associated with the system handle, if you create multiple duplicates of the same handle reading in one instance advances the position in all.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


File(IpcFileHandle)

Read directly from disk.



Bytes(IpcBytes)

Read from allocated bytes.

Implementations

Source

impl IpcReadHandle

pub fn best_read_blocking(file: File) -> Result<IpcReadHandle, Error>

Either keep the handle or read to bytes, whichever is likely to be faster for the common usage pattern of sending to another process and a single full read with some seeking.

pub async fn best_read(file: File) -> Result<IpcReadHandle, Error>

Either keep the handle or read to bytes, whichever is likely to be faster for the common usage pattern of sending to another process and a single full read with some seeking.

pub fn duplicate(&self) -> Result<IpcReadHandle, Error>

Duplicate file handle or clone reference to bytes.

pub fn read_blocking(self) -> Result<IpcReadBlocking, Error>

Begin reading using the std blocking API.

pub async fn read(self) -> Result<IpcRead, Error>

Begin reading using the async API.

pub fn read_to_bytes_blocking(self) -> Result<IpcBytes, Error>

Read file to new IpcBytes or unwrap bytes.

pub async fn read_to_bytes(self) -> Result<IpcBytes, Error>

Read file to new IpcBytes or unwrap bytes.

pub async fn duplicate_or_read(&mut self) -> Result<IpcReadHandle, Error>

Attempts duplicate with read fallback.

If duplicate fails attempts read_to_bytes, if it succeeds replaces self with read bytes and returns a clone if it fails replaces self with empty and returns the read error.

pub fn duplicate_or_read_blocking(&mut self) -> Result<IpcReadHandle, Error>

Attempts duplicate with read fallback.

If duplicate fails attempts read_to_bytes_blocking, if it succeeds replaces self with read bytes and returns a clone if it fails replaces self with empty and returns the read error.