cleanup_memmap_storage

Function cleanup_memmap_storage 

pub fn cleanup_memmap_storage()
If built with "ipc" feature removes all leftover memmap files of crashed processes.

Note that this is already called on normal process exit if any memmap was created. It is also called by the crash handler process on startup after it spawns the app-process.