pub struct IpcFileHandle { /* private fields */ }Expand description
File handle that can be transferred to another process.
File
This type can be converted from and to std::fs::File. This type does not
implement IO traits, it must be converted to read/write. The file handle is only closed on drop
if it was not converted back.
Serialization
This type implements serialization only for compatibility with IPC channel, attempting to
serialize it outside of with_ipc_serialization context will return an error. On IPC serialization
the handle is duplicated for the target process.
Implementations
Sourceimpl IpcFileHandle
impl IpcFileHandle
Sourcepub fn duplicate(&self) -> Result<IpcFileHandle, Error>
pub fn duplicate(&self) -> Result<IpcFileHandle, Error>
Duplicate file handle for the same process.
Note that the read/write offset is associated with the system handle, if you convert
multiple duplicates to File any read in one instance advances the position in all instances.