pub enum CacheMode {
NoCache,
Default,
Permanent,
}Expand description
Request cache mode.
Variants
NoCache
Always requests the server, never caches the response.
Default
Follow the standard cache policy as computed by http-cache-semantics.
Permanent
Always caches the response, overwriting cache control configs.
If the response is cached returns it instead of requesting an update.