StderrTap

Struct StderrTap 

pub struct StderrTap(/* private fields */);
Record stderr of a child process while also passing though the output to the running process output.

Both blocking and async APIs are provided, the blocking API is slightly more efficient.

Implementations

Source

impl StderrTap

pub fn new_blocking(stream: ChildStderr) -> StderrTap

Start recording and passing.

pub fn new(stream: ChildStderr) -> StderrTap

Start recording and passing.

pub fn into_panic_blocking(self) -> Result<PanicInfo, Txt>

Block until the child process closes stderr and attempts to parse the last panic info from it.

If cannot find a panic returns Err with the captured stderr converted to Txt.

Note that the exit code for a fatal panic is 101, checking the exit code is the reliable way to verify the child process exited due to panic.

pub async fn into_panic(self) -> Result<PanicInfo, Txt>

Await until the child process closes stderr and attempts to parse the last panic info from it.

If cannot find a panic returns Err with the captured stderr converted to Txt.

Note that the exit code for a fatal panic is 101, checking the exit code is the reliable way to verify the child process exited due to panic.

Source

impl StderrTap

pub fn dummy() -> StderrTap

Placeholder tap that records nothing.

pub fn into_string_blocking(self, remove_ansi_csi: bool) -> String

Block until the child process closes the stream and converts the capture to String.

pub async fn into_string(self, remove_ansi_csi: bool) -> String

Await until the child process closes the stream and converts the capture to String.

pub fn into_txt_blocking(self, remove_ansi_csi: bool) -> Txt

Block until the child process closes the stream and converts the capture to Txt.

pub async fn into_txt(self, remove_ansi_csi: bool) -> Txt

Await until the child process closes the stream and converts the capture to Txt.