StdoutTap

Struct StdoutTap 

pub struct StdoutTap(/* private fields */);
Record stdout of a child process while also passing though the output to the running process output.

Both blocking and async APIs are provided, the blocking API is slightly more efficient.

Implementations

Source

impl StdoutTap

pub fn new_blocking(stream: ChildStdout) -> StdoutTap

Start recording and passing.

pub fn new(stream: ChildStdout) -> StdoutTap

Start recording and passing.

Source

impl StdoutTap

pub fn dummy() -> StdoutTap

Placeholder tap that records nothing.

pub fn into_string_blocking(self, remove_ansi_csi: bool) -> String

Block until the child process closes the stream and converts the capture to String.

pub async fn into_string(self, remove_ansi_csi: bool) -> String

Await until the child process closes the stream and converts the capture to String.

pub fn into_txt_blocking(self, remove_ansi_csi: bool) -> Txt

Block until the child process closes the stream and converts the capture to Txt.

pub async fn into_txt(self, remove_ansi_csi: bool) -> Txt

Await until the child process closes the stream and converts the capture to Txt.