rich_text

Function rich_text 

pub fn rich_text(wgt: &mut WidgetBuilding, enabled: impl IntoVar<bool>)
B Defines a rich text context.

When enabled text widget descendants of this widget edit the text across the widgets, for example, the caret position moves to the next text widget when it reaches the start/end of the first text widget.

Nested rich text contexts are allowed and are all part of the outermost context, enabling this property in all nested wrap panels is recommended as it enables some rich text behavior like bringing the focused widget to front to avoid clipping the caret.

When enabled and not nested the widget will handle text commands, it also broadcasts focus change events to all text descendants.

Mixin Property

This property is a mixin, it modifies the widget builder during build, it does not produce a standalone UI node.