pub struct LangMix<P>(/* private fields */);Expand description
m Language and text direction properties.
All properties in this mixin affects Text! nodes inside the widget where they are set.
Implementations
Sourceimpl<P> LangMix<P>where
P: WidgetImpl,
impl<P> LangMix<P>where
P: WidgetImpl,
Sourcepub fn lang(&self, lang: impl IntoVar<Langs>)
pub fn lang(&self, lang: impl IntoVar<Langs>)
P Sets the text language and script for the widget and descendants.
This property affects all texts inside the widget and the layout direction.
Sets the LANG_VAR and DIRECTION_VAR context vars and the LayoutMetrics::direction.
Also sets the access::lang when accessibility is enabled.
Sourceimpl<P> LangMix<P>where
P: WidgetImpl,
impl<P> LangMix<P>where
P: WidgetImpl,
Sourcepub fn direction(&self, direction: impl IntoVar<LayoutDirection>)
pub fn direction(&self, direction: impl IntoVar<LayoutDirection>)
P Sets the layout direction used in the layout of the widget and descendants.
Note that the lang property already sets the direction, this property can be used to directly override the direction.
Sets the DIRECTION_VAR context var and the LayoutMetrics::direction.
Sourceimpl LangMix<()>
impl LangMix<()>
Sourcepub fn context_vars_set(set: &mut ContextValueSet)
pub fn context_vars_set(set: &mut ContextValueSet)
Insert context variables used by properties in this mixin.