pub struct ParagraphMix<P>(/* private fields */);Expand description
m Text paragraph properties.
The base Text! widget only implements minimal support for paragraphs, rich text widgets will probably
segment paragraphs into sub widgets and may ignore PARAGRAPH_BREAK_VAR depending on the source text format.
Implementations
Sourceimpl ParagraphMix<()>
impl ParagraphMix<()>
Sourcepub fn context_vars_set(set: &mut ContextValueSet)
pub fn context_vars_set(set: &mut ContextValueSet)
Insert context variables used by properties in this mixin.
Sourceimpl<P> ParagraphMix<P>where
P: WidgetImpl,
impl<P> ParagraphMix<P>where
P: WidgetImpl,
Sourcepub fn paragraph_break(&self, mode: impl IntoVar<ParagraphBreak>)
pub fn paragraph_break(&self, mode: impl IntoVar<ParagraphBreak>)
P Defines paragraphs in the text.
In the base Text! widget this defines how paragraph_spacing and paragraph_indent are applied.
Other rich text widgets usually segment paragraphs into widgets and may ignore this property, depending on the source text format.
Sets the PARAGRAPH_BREAK_VAR.
Sourceimpl<P> ParagraphMix<P>where
P: WidgetImpl,
impl<P> ParagraphMix<P>where
P: WidgetImpl,
Sourcepub fn paragraph_spacing(&self, extra: impl IntoVar<Length>)
pub fn paragraph_spacing(&self, extra: impl IntoVar<Length>)
P Extra spacing in-between paragraphs.
The default value is 1.em(). Note that paragraph_break defines the entire text as a single paragraph
by default, so this will not be applied by default on the base Text! widget.
Sets the PARAGRAPH_SPACING_VAR.
Sourceimpl<P> ParagraphMix<P>where
P: WidgetImpl,
impl<P> ParagraphMix<P>where
P: WidgetImpl,
Sourcepub fn paragraph_indent(&self, indent: impl IntoVar<Indentation>)
pub fn paragraph_indent(&self, indent: impl IntoVar<Indentation>)
P Extra spacing added at the start of lines in a paragraph.
This can be set to a width Length to insert spacing at the start of each first line,
or it can be set to (Length, true) to hang all lines except the first.
See paragraph_break for how to define paragraphs.
Sets the PARAGRAPH_INDENT_VAR.