pub struct Selector(/* private fields */);Expand description
Implementations
Sourceimpl Selector
impl Selector
Sourcepub fn new(selector: impl SelectorImpl) -> Selector
pub fn new(selector: impl SelectorImpl) -> Selector
New custom selector.
Sourcepub fn single<T>(selection: impl IntoVar<T>) -> Selectorwhere
T: VarValue,
pub fn single<T>(selection: impl IntoVar<T>) -> Selectorwhere
T: VarValue,
Represents the “radio” selection of a single item.
Sourcepub fn single_opt<T>(selection: impl IntoVar<Option<T>>) -> Selectorwhere
T: VarValue,
pub fn single_opt<T>(selection: impl IntoVar<Option<T>>) -> Selectorwhere
T: VarValue,
Represents the “radio” selection of a single item that is optional.
Sourcepub fn bitflags<T>(selection: impl IntoVar<T>) -> Selector
pub fn bitflags<T>(selection: impl IntoVar<T>) -> Selector
Represents the “check list” selection of bitflags.
Sourcepub fn select(&self, value: BoxAnyVarValue) -> Result<(), SelectorError>
pub fn select(&self, value: BoxAnyVarValue) -> Result<(), SelectorError>
Insert the value in the selection, returns Ok(()) if the value was inserted or was already selected.
Sourcepub fn deselect(
&self,
value: &(dyn AnyVarValue + 'static),
) -> Result<(), SelectorError>
pub fn deselect( &self, value: &(dyn AnyVarValue + 'static), ) -> Result<(), SelectorError>
Remove the value from the selection, returns Ok(()) if the value was removed or was not selected.
Sourcepub fn is_selected(&self, value: &(dyn AnyVarValue + 'static)) -> bool
pub fn is_selected(&self, value: &(dyn AnyVarValue + 'static)) -> bool
Returns true if the value is selected.
Sourcepub fn downgrade(&self) -> WeakSelector
pub fn downgrade(&self) -> WeakSelector
Create a WeakSelector pointer to this selector.
Sourcepub fn strong_count(&self) -> usize
pub fn strong_count(&self) -> usize
Number of strong pointers to this selector.