Function on_pre_disabled_touch_long_press
Source pub fn on_pre_disabled_touch_long_press(
child: impl IntoUiNode,
handler: Box<dyn FnMut(&TouchLongPressArgs) -> HandlerResult + Send>,
) -> UiNode
P Single touch contact was made and held in place for a duration of time (default 500ms) on
the widget and the widget is disabled.
Route
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the
$pn_ident
handlers.