on_pre_touch_leave

Function on_pre_touch_leave 

pub fn on_pre_touch_leave(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&TouchedArgs) -> HandlerResult + Send>,
) -> UiNode
P Touch contact is no longer over the widget or any descendant and it is enabled.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.