on_pre_touch_start

Function on_pre_touch_start 

pub fn on_pre_touch_start(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&TouchInputArgs) -> HandlerResult + Send>,
) -> UiNode
P Touch contact started over the widget, it is enabled and cursor capture allows it.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.