on_pre_touch_transform

Function on_pre_touch_transform 

pub fn on_pre_touch_transform(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&TouchTransformArgs) -> HandlerResult + Send>,
) -> UiNode
P Touch gesture to translate, scale or rotate happened over this widget.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.