pub fn on_touch_enter(
child: impl IntoUiNode,
handler: Box<dyn FnMut(&TouchedArgs) -> HandlerResult + Send>,
) -> UiNodeExpand description
P Touch contact is now over the widget or a descendant and it is enabled.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.