pub fn on_touch_long_press(
child: impl IntoUiNode,
handler: Box<dyn FnMut(&TouchLongPressArgs) -> HandlerResult + Send>,
) -> UiNodeExpand description
P Single touch contact was made and held in place for a duration of time (default 500ms) on
the widget and the widget is enabled.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.