on_touch_start

Function on_touch_start 

pub fn on_touch_start(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&TouchInputArgs) -> HandlerResult + Send>,
) -> UiNode
P Touch contact started over the widget, it is enabled and cursor capture allows it.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.