on_touch_tap

Function on_touch_tap 

pub fn on_touch_tap(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&TouchTapArgs) -> HandlerResult + Send>,
) -> UiNode
P Touch tap on the widget and it is enabled.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.