pub fn on_touched(
child: impl IntoUiNode,
handler: Box<dyn FnMut(&TouchedArgs) -> HandlerResult + Send>,
) -> UiNodeExpand description
P Touch contact entered or left the widget and descendants area and it is enabled.
You can use the is_touch_enter and is_touch_leave methods to determinate the state change.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.