pub struct TouchMoveArgs {
pub timestamp: DInstant,
pub window_id: WindowId,
pub device_id: InputDeviceId,
pub touches: Vec<TouchMove>,
pub capture: Option<CaptureInfo>,
pub modifiers: ModifiersState,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for TOUCH_MOVE_EVENT.
Fields
timestamp: DInstantInstant the event happened.
window_id: WindowIdId of window that received all touches in this event.
device_id: InputDeviceIdId of device that generated all touches in this event.
touches: Vec<TouchMove>All touch contacts that moved since last event.
Note that if a touch contact did not move it will not be in the list, the touch may still be active
however, the TOUCH_INPUT_EVENT can be used to track touch start and end.
capture: Option<CaptureInfo>Current pointer capture.
modifiers: ModifiersStateWhat modifier keys where pressed when this event happened.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl TouchMoveArgs
impl TouchMoveArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
window_id: impl Into<WindowId>,
device_id: impl Into<InputDeviceId>,
touches: impl Into<Vec<TouchMove>>,
capture: impl Into<Option<CaptureInfo>>,
modifiers: impl Into<ModifiersState>,
) -> TouchMoveArgs
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, window_id: impl Into<WindowId>, device_id: impl Into<InputDeviceId>, touches: impl Into<Vec<TouchMove>>, capture: impl Into<Option<CaptureInfo>>, modifiers: impl Into<ModifiersState>, ) -> TouchMoveArgs
New args from values that convert into the argument types.
Sourcepub fn now(
window_id: impl Into<WindowId>,
device_id: impl Into<InputDeviceId>,
touches: impl Into<Vec<TouchMove>>,
capture: impl Into<Option<CaptureInfo>>,
modifiers: impl Into<ModifiersState>,
) -> TouchMoveArgs
pub fn now( window_id: impl Into<WindowId>, device_id: impl Into<InputDeviceId>, touches: impl Into<Vec<TouchMove>>, capture: impl Into<Option<CaptureInfo>>, modifiers: impl Into<ModifiersState>, ) -> TouchMoveArgs
Arguments for event that happened now (INSTANT.now).
Sourceimpl TouchMoveArgs
impl TouchMoveArgs