pub struct UpdateDeliveryList { /* private fields */ }Expand description
Represents all the widgets and windows marked to receive an update.
Implementations
Sourceimpl UpdateDeliveryList
impl UpdateDeliveryList
Sourcepub fn new() -> UpdateDeliveryList
pub fn new() -> UpdateDeliveryList
New list that only allows subscribers.
Sourcepub fn insert_wgt(&mut self, wgt: impl WidgetPathProvider)
pub fn insert_wgt(&mut self, wgt: impl WidgetPathProvider)
Insert the wgt and ancestors up-to the inner most that is included in the subscribers.
Sourcepub fn clone_insert_wgt(
&self,
wgt: impl WidgetPathProvider,
) -> Cow<'_, UpdateDeliveryList>
pub fn clone_insert_wgt( &self, wgt: impl WidgetPathProvider, ) -> Cow<'_, UpdateDeliveryList>
If the delivery list does not contain the wgt clones the list and inserts the widget.
If the list already contains the widget returns the reference.
Sourcepub fn clone_insert_all<W>(
&self,
widgets: impl IntoIterator<Item = W>,
) -> Cow<'_, UpdateDeliveryList>where
W: WidgetPathProvider,
pub fn clone_insert_all<W>(
&self,
widgets: impl IntoIterator<Item = W>,
) -> Cow<'_, UpdateDeliveryList>where
W: WidgetPathProvider,
If the delivery list does not contain all widgets clones the list and inserts all widgets.
If the list already contains all widgets returns the reference.
Sourcepub fn clone_insert_any<W>(
&self,
widgets: impl IntoIterator<Item = W>,
) -> Cow<'_, UpdateDeliveryList>where
W: WidgetPathProvider,
pub fn clone_insert_any<W>(
&self,
widgets: impl IntoIterator<Item = W>,
) -> Cow<'_, UpdateDeliveryList>where
W: WidgetPathProvider,
If the delivery list does not contain any widgets clones the list and inserts the first missing widget.
If the list already contains at least one widget returns the reference.
Sourcepub fn insert_window(&mut self, id: WindowId)
pub fn insert_window(&mut self, id: WindowId)
Insert the window by itself, the window root widget will be targeted.
Sourcepub fn search_widget(&mut self, widget_id: WidgetId)
pub fn search_widget(&mut self, widget_id: WidgetId)
Register the widget of unknown location for search before delivery routing starts.
Sourcepub fn has_pending_search(&mut self) -> bool
pub fn has_pending_search(&mut self) -> bool
If the list has pending widgets that must be found before delivery can start.
Sourcepub fn fulfill_search<'a, 'b>(
&'a mut self,
windows: impl Iterator<Item = &'b WidgetInfoTree>,
)
pub fn fulfill_search<'a, 'b>( &'a mut self, windows: impl Iterator<Item = &'b WidgetInfoTree>, )
Search all pending widgets in all windows, all search items are cleared, even if not found.
Sourcepub fn enter_window(&self, window_id: WindowId) -> bool
pub fn enter_window(&self, window_id: WindowId) -> bool
Returns true if the window is on the list.
Sourcepub fn enter_widget(&self, widget_id: WidgetId) -> bool
pub fn enter_widget(&self, widget_id: WidgetId) -> bool
Returns true if the widget is on the list.
Sourcepub fn widgets(&self) -> &IdSet<WidgetId>
pub fn widgets(&self) -> &IdSet<WidgetId>
Found widgets in the delivery list, can be targets or ancestors of targets.
Sourcepub fn search_widgets(&mut self) -> &IdSet<WidgetId>
pub fn search_widgets(&mut self) -> &IdSet<WidgetId>
Widgets still pending search or not found.
Sourcepub fn search_root(&mut self) -> bool
pub fn search_root(&mut self) -> bool
If search for window a root is pending.
Sourcepub fn extend(&mut self, other: UpdateDeliveryList)
pub fn extend(&mut self, other: UpdateDeliveryList)
Copy windows, widgets and search from other.