pub struct AnyMergeVarBuilder { /* private fields */ }Expand description
Build a merge_var! from any number of input vars of any type.
Implementations
Sourceimpl AnyMergeVarBuilder
impl AnyMergeVarBuilder
Sourcepub fn new() -> AnyMergeVarBuilder
pub fn new() -> AnyMergeVarBuilder
new empty.
Sourcepub fn with_capacity(capacity: usize) -> AnyMergeVarBuilder
pub fn with_capacity(capacity: usize) -> AnyMergeVarBuilder
New with pre-allocated inputs.
Sourcepub fn build_any(
self,
merge: impl FnMut(&[AnyVar]) -> BoxAnyVarValue + Send + 'static,
output_type: TypeId,
) -> AnyVar
pub fn build_any( self, merge: impl FnMut(&[AnyVar]) -> BoxAnyVarValue + Send + 'static, output_type: TypeId, ) -> AnyVar
Build a read-only merge var.
Sourcepub fn build<O>(
self,
merge: impl FnMut(&[AnyVar]) -> O + Send + 'static,
) -> Var<O>where
O: VarValue,
pub fn build<O>(
self,
merge: impl FnMut(&[AnyVar]) -> O + Send + 'static,
) -> Var<O>where
O: VarValue,
Build a read-only strongly typed merge var.
Sourcepub fn build_bidi_any(
self,
merge: impl FnMut(&[AnyVar]) -> BoxAnyVarValue + Send + 'static,
map_back: impl FnMut(&(dyn AnyVarValue + 'static), usize) -> BoxAnyVarValue + Send + 'static,
output_type: TypeId,
) -> AnyVar
pub fn build_bidi_any( self, merge: impl FnMut(&[AnyVar]) -> BoxAnyVarValue + Send + 'static, map_back: impl FnMut(&(dyn AnyVarValue + 'static), usize) -> BoxAnyVarValue + Send + 'static, output_type: TypeId, ) -> AnyVar
Build a read-write merge var.
Sourcepub fn build_bidi_any_modify(
self,
merge: impl FnMut(&[AnyVar]) -> BoxAnyVarValue + Send + 'static,
modify_back: impl FnMut(&(dyn AnyVarValue + 'static), usize, &mut AnyVarModify<'_>) + Send + 'static,
output_type: TypeId,
) -> AnyVar
pub fn build_bidi_any_modify( self, merge: impl FnMut(&[AnyVar]) -> BoxAnyVarValue + Send + 'static, modify_back: impl FnMut(&(dyn AnyVarValue + 'static), usize, &mut AnyVarModify<'_>) + Send + 'static, output_type: TypeId, ) -> AnyVar
Build a read-write merge var that modifies each input back.
Sourcepub fn build_bidi<O>(
self,
merge: impl FnMut(&[AnyVar]) -> O + Send + 'static,
map_back: impl FnMut(&O, usize) -> BoxAnyVarValue + Send + 'static,
) -> Var<O>where
O: VarValue,
pub fn build_bidi<O>(
self,
merge: impl FnMut(&[AnyVar]) -> O + Send + 'static,
map_back: impl FnMut(&O, usize) -> BoxAnyVarValue + Send + 'static,
) -> Var<O>where
O: VarValue,
Build a read-write strongly typed merge var.
Sourcepub fn build_bidi_modify<O>(
self,
merge: impl FnMut(&[AnyVar]) -> O + Send + 'static,
modify_back: impl FnMut(&O, usize, &mut AnyVarModify<'_>) + Send + 'static,
) -> Var<O>where
O: VarValue,
pub fn build_bidi_modify<O>(
self,
merge: impl FnMut(&[AnyVar]) -> O + Send + 'static,
modify_back: impl FnMut(&O, usize, &mut AnyVarModify<'_>) + Send + 'static,
) -> Var<O>where
O: VarValue,
Build a read-write strongly typed merge var that modifies each input back.
Sourcepub fn into_typed<I>(self) -> MergeVarBuilder<I>where
I: VarValue,
pub fn into_typed<I>(self) -> MergeVarBuilder<I>where
I: VarValue,