pub trait IntoVar<T>where
T: VarValue,{
// Required method
fn into_var(self) -> Var<T>;
}Expand description
A value-to-var conversion that consumes the value.
Every Var<T> implements this to convert to itself, every VarValue implements this to
convert to a const_var.
This trait is used by most properties, it allows then to accept literal values, variables and context variables
all with a single signature. Together with Var<T> this gives properties great flexibility of usage. Widget
when blocks also use IntoVar<T> to support changing the property value depending on the widget state.
Value types can also manually implement this to support a shorthand literal syntax for when they are used in properties,
this converts the shorthand value like a tuple into the actual value type and wraps it into a variable, usually const_var.
Value types can implement the trait multiple times to support different shorthand syntaxes.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl IntoVar<AudioCacheMode> for bool
impl IntoVar<AudioCacheMode> for bool
fn into_var(self) -> Var<AudioCacheMode>
Sourceimpl IntoVar<AudioOutputId> for &'static str
impl IntoVar<AudioOutputId> for &'static str
Sourcefn into_var(self) -> Var<AudioOutputId>
fn into_var(self) -> Var<AudioOutputId>
Calls AudioOutputId::named.
Sourceimpl IntoVar<AudioOutputId> for Cow<'static, str>
impl IntoVar<AudioOutputId> for Cow<'static, str>
Sourcefn into_var(self) -> Var<AudioOutputId>
fn into_var(self) -> Var<AudioOutputId>
Calls AudioOutputId::named.
Sourceimpl IntoVar<AudioOutputId> for String
impl IntoVar<AudioOutputId> for String
Sourcefn into_var(self) -> Var<AudioOutputId>
fn into_var(self) -> Var<AudioOutputId>
Calls AudioOutputId::named.
Sourceimpl IntoVar<AudioOutputId> for char
impl IntoVar<AudioOutputId> for char
Sourcefn into_var(self) -> Var<AudioOutputId>
fn into_var(self) -> Var<AudioOutputId>
Calls AudioOutputId::named.
Sourceimpl IntoVar<AudioSource> for &Path
impl IntoVar<AudioSource> for &Path
fn into_var(self) -> Var<AudioSource>
Sourceimpl IntoVar<AudioSource> for &[u8]
impl IntoVar<AudioSource> for &[u8]
Sourceimpl IntoVar<AudioSource> for &str
impl IntoVar<AudioSource> for &str
Sourceimpl IntoVar<AudioSource> for (Uri, &'static str)
impl IntoVar<AudioSource> for (Uri, &'static str)
Sourcefn into_var(self) -> Var<AudioSource>
fn into_var(self) -> Var<AudioSource>
From (URI, HTTP-ACCEPT).
Sourceimpl IntoVar<AudioSource> for PathBuf
impl IntoVar<AudioSource> for PathBuf
fn into_var(self) -> Var<AudioSource>
Sourceimpl IntoVar<AudioSource> for String
impl IntoVar<AudioSource> for String
Sourcefn into_var(self) -> Var<AudioSource>
fn into_var(self) -> Var<AudioSource>
Same as conversion from &str.
Sourceimpl IntoVar<AutoSelection> for bool
impl IntoVar<AutoSelection> for bool
fn into_var(self) -> Var<AutoSelection>
Sourceimpl IntoVar<BlockWindowLoad> for Duration
impl IntoVar<BlockWindowLoad> for Duration
Sourcefn into_var(self) -> Var<BlockWindowLoad>
fn into_var(self) -> Var<BlockWindowLoad>
Converts to enabled with the duration timeout.
Sourceimpl IntoVar<BlockWindowLoad> for bool
impl IntoVar<BlockWindowLoad> for bool
Sourcefn into_var(self) -> Var<BlockWindowLoad>
fn into_var(self) -> Var<BlockWindowLoad>
Converts true to BlockWindowLoad::enabled(1.secs()) and false to BlockWindowLoad::Disabled.
Sourceimpl IntoVar<BorderRepeats> for bool
impl IntoVar<BorderRepeats> for bool
Sourcefn into_var(self) -> Var<BorderRepeats>
fn into_var(self) -> Var<BorderRepeats>
true is Repeat, false is Stretch.
Sourceimpl IntoVar<ByteLength> for u64
impl IntoVar<ByteLength> for u64
fn into_var(self) -> Var<ByteLength>
Sourceimpl IntoVar<CaptureMode> for bool
impl IntoVar<CaptureMode> for bool
Sourcefn into_var(self) -> Var<CaptureMode>
fn into_var(self) -> Var<CaptureMode>
Convert true to CaptureMode::Widget and false to CaptureMode::Window.
Sourceimpl IntoVar<CaretIndex> for usize
impl IntoVar<CaretIndex> for usize
fn into_var(self) -> Var<CaretIndex>
Sourceimpl IntoVar<CategoryId> for &'static str
impl IntoVar<CategoryId> for &'static str
fn into_var(self) -> Var<CategoryId>
Sourceimpl IntoVar<CategoryId> for String
impl IntoVar<CategoryId> for String
fn into_var(self) -> Var<CategoryId>
Sourceimpl IntoVar<CharVariant> for u8
impl IntoVar<CharVariant> for u8
Sourcefn into_var(self) -> Var<CharVariant>
fn into_var(self) -> Var<CharVariant>
v == 0 || v > 99 is Auto, v >= 1 && v <= 99 maps to their variant.
Sourceimpl IntoVar<CollapseMode> for bool
impl IntoVar<CollapseMode> for bool
fn into_var(self) -> Var<CollapseMode>
Sourceimpl IntoVar<CommandScope> for &'static str
impl IntoVar<CommandScope> for &'static str
Sourcefn into_var(self) -> Var<CommandScope>
fn into_var(self) -> Var<CommandScope>
Widget scope.
Sourceimpl IntoVar<ContextCapture> for bool
impl IntoVar<ContextCapture> for bool
fn into_var(self) -> Var<ContextCapture>
Sourceimpl IntoVar<CornerRadius> for f32
impl IntoVar<CornerRadius> for f32
Sourcefn into_var(self) -> Var<CornerRadius>
fn into_var(self) -> Var<CornerRadius>
All corners same exact length.
Sourceimpl IntoVar<CornerRadius> for i32
impl IntoVar<CornerRadius> for i32
Sourcefn into_var(self) -> Var<CornerRadius>
fn into_var(self) -> Var<CornerRadius>
All corners same exact length.
Sourceimpl IntoVar<CursorSource> for bool
impl IntoVar<CursorSource> for bool
Sourcefn into_var(self) -> Var<CursorSource>
fn into_var(self) -> Var<CursorSource>
Converts true to CursorIcon::Default and false to CursorSource::Hidden.
Sourceimpl IntoVar<DialogKind> for bool
impl IntoVar<DialogKind> for bool
fn into_var(self) -> Var<DialogKind>
Sourceimpl IntoVar<FileDialogFilters> for &'static str
impl IntoVar<FileDialogFilters> for &'static str
fn into_var(self) -> Var<FileDialogFilters>
Sourceimpl IntoVar<FontAntiAliasing> for bool
impl IntoVar<FontAntiAliasing> for bool
Sourcefn into_var(self) -> Var<FontAntiAliasing>
fn into_var(self) -> Var<FontAntiAliasing>
Convert true to Subpixel and false to Mono.
Sourceimpl IntoVar<FontColorPalette> for u16
impl IntoVar<FontColorPalette> for u16
fn into_var(self) -> Var<FontColorPalette>
Sourceimpl IntoVar<FontFeatureState> for bool
impl IntoVar<FontFeatureState> for bool
fn into_var(self) -> Var<FontFeatureState>
Sourceimpl IntoVar<FontFeatureState> for u32
impl IntoVar<FontFeatureState> for u32
Sourcefn into_var(self) -> Var<FontFeatureState>
fn into_var(self) -> Var<FontFeatureState>
0 is disabled, >=1 is enabled with the alt value.
Sourceimpl IntoVar<FontStretch> for f32
impl IntoVar<FontStretch> for f32
fn into_var(self) -> Var<FontStretch>
Sourceimpl IntoVar<FontStyleSet> for u8
impl IntoVar<FontStyleSet> for u8
fn into_var(self) -> Var<FontStyleSet>
Sourceimpl IntoVar<FontSynthesis> for bool
impl IntoVar<FontSynthesis> for bool
Sourceimpl IntoVar<FontWeight> for f32
impl IntoVar<FontWeight> for f32
fn into_var(self) -> Var<FontWeight>
Sourceimpl IntoVar<FontWeight> for u32
impl IntoVar<FontWeight> for u32
fn into_var(self) -> Var<FontWeight>
Sourceimpl IntoVar<GlyphSource> for &'static str
impl IntoVar<GlyphSource> for &'static str
fn into_var(self) -> Var<GlyphSource>
Sourceimpl IntoVar<GlyphSource> for char
impl IntoVar<GlyphSource> for char
fn into_var(self) -> Var<GlyphSource>
Sourceimpl IntoVar<GradientRadius> for f32
impl IntoVar<GradientRadius> for f32
Sourcefn into_var(self) -> Var<GradientRadius>
fn into_var(self) -> Var<GradientRadius>
Conversion to Length::DipF32 and to radius.
Sourceimpl IntoVar<GradientRadius> for i32
impl IntoVar<GradientRadius> for i32
Sourcefn into_var(self) -> Var<GradientRadius>
fn into_var(self) -> Var<GradientRadius>
Conversion to Length::Dip and to radius.
Sourceimpl IntoVar<GradientStop> for f32
impl IntoVar<GradientStop> for f32
Sourcefn into_var(self) -> Var<GradientStop>
fn into_var(self) -> Var<GradientStop>
Conversion to Length::Dip color hint.
Sourceimpl IntoVar<GradientStop> for i32
impl IntoVar<GradientStop> for i32
Sourcefn into_var(self) -> Var<GradientStop>
fn into_var(self) -> Var<GradientStop>
Conversion to Length::Dip color hint.
Sourceimpl IntoVar<GradientStops> for &[Hsla]
impl IntoVar<GradientStops> for &[Hsla]
Sourcefn into_var(self) -> Var<GradientStops>
fn into_var(self) -> Var<GradientStops>
Sourceimpl IntoVar<GradientStops> for &[Hsva]
impl IntoVar<GradientStops> for &[Hsva]
Sourcefn into_var(self) -> Var<GradientStops>
fn into_var(self) -> Var<GradientStops>
Sourceimpl IntoVar<GradientStops> for &[Rgba]
impl IntoVar<GradientStops> for &[Rgba]
Sourcefn into_var(self) -> Var<GradientStops>
fn into_var(self) -> Var<GradientStops>
Sourceimpl IntoVar<GridSpacing> for f32
impl IntoVar<GridSpacing> for f32
Sourcefn into_var(self) -> Var<GridSpacing>
fn into_var(self) -> Var<GridSpacing>
Column and row equal exact length.
Sourceimpl IntoVar<GridSpacing> for i32
impl IntoVar<GridSpacing> for i32
Sourcefn into_var(self) -> Var<GridSpacing>
fn into_var(self) -> Var<GridSpacing>
Column and row equal exact length.
Sourceimpl IntoVar<HitTestMode> for bool
impl IntoVar<HitTestMode> for bool
fn into_var(self) -> Var<HitTestMode>
Sourceimpl IntoVar<ImageAutoScale> for bool
impl IntoVar<ImageAutoScale> for bool
fn into_var(self) -> Var<ImageAutoScale>
Sourceimpl IntoVar<ImageCacheMode> for bool
impl IntoVar<ImageCacheMode> for bool
fn into_var(self) -> Var<ImageCacheMode>
Sourceimpl IntoVar<ImageDownscaleMode> for Size2D<Px, Px>
impl IntoVar<ImageDownscaleMode> for Size2D<Px, Px>
fn into_var(self) -> Var<ImageDownscaleMode>
Sourceimpl IntoVar<ImageRepeat> for bool
impl IntoVar<ImageRepeat> for bool
fn into_var(self) -> Var<ImageRepeat>
Sourceimpl IntoVar<ImageSource> for &Path
impl IntoVar<ImageSource> for &Path
fn into_var(self) -> Var<ImageSource>
Sourceimpl IntoVar<ImageSource> for &[u8]
impl IntoVar<ImageSource> for &[u8]
Sourceimpl IntoVar<ImageSource> for &str
impl IntoVar<ImageSource> for &str
Sourceimpl IntoVar<ImageSource> for (Uri, &'static str)
impl IntoVar<ImageSource> for (Uri, &'static str)
Sourcefn into_var(self) -> Var<ImageSource>
fn into_var(self) -> Var<ImageSource>
From (URI, HTTP-ACCEPT).
Sourceimpl IntoVar<ImageSource> for PathBuf
impl IntoVar<ImageSource> for PathBuf
fn into_var(self) -> Var<ImageSource>
Sourceimpl IntoVar<ImageSource> for String
impl IntoVar<ImageSource> for String
Sourcefn into_var(self) -> Var<ImageSource>
fn into_var(self) -> Var<ImageSource>
Same as conversion from &str.
Sourceimpl IntoVar<Importance> for u32
impl IntoVar<Importance> for u32
fn into_var(self) -> Var<Importance>
Sourceimpl IntoVar<Indentation> for f32
impl IntoVar<Indentation> for f32
fn into_var(self) -> Var<Indentation>
Sourceimpl IntoVar<Indentation> for i32
impl IntoVar<Indentation> for i32
fn into_var(self) -> Var<Indentation>
Sourceimpl IntoVar<InlineMode> for bool
impl IntoVar<InlineMode> for bool
fn into_var(self) -> Var<InlineMode>
Sourceimpl IntoVar<InspectMode> for bool
impl IntoVar<InspectMode> for bool
fn into_var(self) -> Var<InspectMode>
Sourceimpl IntoVar<InteractiveCaretMode> for bool
impl IntoVar<InteractiveCaretMode> for bool
fn into_var(self) -> Var<InteractiveCaretMode>
Sourceimpl IntoVar<Interactivity> for bool
impl IntoVar<Interactivity> for bool
Sourcefn into_var(self) -> Var<Interactivity>
fn into_var(self) -> Var<Interactivity>
true->ENABLEDfalse->DISABLED
Sourceimpl IntoVar<L10nArgument> for &'static str
impl IntoVar<L10nArgument> for &'static str
fn into_var(self) -> Var<L10nArgument>
Sourceimpl IntoVar<L10nArgument> for FluentNumber
impl IntoVar<L10nArgument> for FluentNumber
fn into_var(self) -> Var<L10nArgument>
Sourceimpl IntoVar<L10nArgument> for String
impl IntoVar<L10nArgument> for String
fn into_var(self) -> Var<L10nArgument>
Sourceimpl IntoVar<L10nArgument> for bool
impl IntoVar<L10nArgument> for bool
fn into_var(self) -> Var<L10nArgument>
Sourceimpl IntoVar<L10nArgument> for char
impl IntoVar<L10nArgument> for char
fn into_var(self) -> Var<L10nArgument>
Sourceimpl IntoVar<L10nArgument> for f32
impl IntoVar<L10nArgument> for f32
fn into_var(self) -> Var<L10nArgument>
Sourceimpl IntoVar<L10nArgument> for f64
impl IntoVar<L10nArgument> for f64
fn into_var(self) -> Var<L10nArgument>
Sourceimpl IntoVar<L10nArgument> for i8
impl IntoVar<L10nArgument> for i8
fn into_var(self) -> Var<L10nArgument>
Sourceimpl IntoVar<L10nArgument> for i16
impl IntoVar<L10nArgument> for i16
fn into_var(self) -> Var<L10nArgument>
Sourceimpl IntoVar<L10nArgument> for i32
impl IntoVar<L10nArgument> for i32
fn into_var(self) -> Var<L10nArgument>
Sourceimpl IntoVar<L10nArgument> for i64
impl IntoVar<L10nArgument> for i64
fn into_var(self) -> Var<L10nArgument>
Sourceimpl IntoVar<L10nArgument> for i128
impl IntoVar<L10nArgument> for i128
fn into_var(self) -> Var<L10nArgument>
Sourceimpl IntoVar<L10nArgument> for isize
impl IntoVar<L10nArgument> for isize
fn into_var(self) -> Var<L10nArgument>
Sourceimpl IntoVar<L10nArgument> for u8
impl IntoVar<L10nArgument> for u8
fn into_var(self) -> Var<L10nArgument>
Sourceimpl IntoVar<L10nArgument> for u16
impl IntoVar<L10nArgument> for u16
fn into_var(self) -> Var<L10nArgument>
Sourceimpl IntoVar<L10nArgument> for u32
impl IntoVar<L10nArgument> for u32
fn into_var(self) -> Var<L10nArgument>
Sourceimpl IntoVar<L10nArgument> for u64
impl IntoVar<L10nArgument> for u64
fn into_var(self) -> Var<L10nArgument>
Sourceimpl IntoVar<L10nArgument> for u128
impl IntoVar<L10nArgument> for u128
fn into_var(self) -> Var<L10nArgument>
Sourceimpl IntoVar<L10nArgument> for usize
impl IntoVar<L10nArgument> for usize
fn into_var(self) -> Var<L10nArgument>
Sourceimpl IntoVar<LangFilePath> for &'static str
impl IntoVar<LangFilePath> for &'static str
fn into_var(self) -> Var<LangFilePath>
Sourceimpl IntoVar<LangFilePath> for String
impl IntoVar<LangFilePath> for String
fn into_var(self) -> Var<LangFilePath>
Sourceimpl IntoVar<LayerIndex> for u32
impl IntoVar<LayerIndex> for u32
fn into_var(self) -> Var<LayerIndex>
Sourceimpl IntoVar<MouseActiveConfig> for (Duration, Size2D<Dip, Dip>)
impl IntoVar<MouseActiveConfig> for (Duration, Size2D<Dip, Dip>)
fn into_var(self) -> Var<MouseActiveConfig>
Sourceimpl IntoVar<MouseActiveConfig> for Duration
impl IntoVar<MouseActiveConfig> for Duration
fn into_var(self) -> Var<MouseActiveConfig>
Sourceimpl IntoVar<MouseActiveConfig> for Size2D<Dip, Dip>
impl IntoVar<MouseActiveConfig> for Size2D<Dip, Dip>
fn into_var(self) -> Var<MouseActiveConfig>
Sourceimpl IntoVar<Option<AccessNodeId>> for AccessNodeId
impl IntoVar<Option<AccessNodeId>> for AccessNodeId
Sourceimpl IntoVar<Option<AccessState>> for AccessState
impl IntoVar<Option<AccessState>> for AccessState
Sourceimpl IntoVar<ParallelWin> for bool
impl IntoVar<ParallelWin> for bool
fn into_var(self) -> Var<ParallelWin>
Sourceimpl IntoVar<PxConstraints2d> for (Size2D<Px, Px>, Size2D<Px, Px>)
impl IntoVar<PxConstraints2d> for (Size2D<Px, Px>, Size2D<Px, Px>)
Sourcefn into_var(self) -> Var<PxConstraints2d>
fn into_var(self) -> Var<PxConstraints2d>
New range, the minimum and maximum is computed.
Sourceimpl IntoVar<PxConstraints2d> for Size2D<Px, Px>
impl IntoVar<PxConstraints2d> for Size2D<Px, Px>
Sourcefn into_var(self) -> Var<PxConstraints2d>
fn into_var(self) -> Var<PxConstraints2d>
New exact.
Sourceimpl IntoVar<RepeatMode> for bool
impl IntoVar<RepeatMode> for bool
Sourcefn into_var(self) -> Var<RepeatMode>
fn into_var(self) -> Var<RepeatMode>
Converts true to Repeat and false to the default Stretch.
Sourceimpl IntoVar<ScrollMode> for bool
impl IntoVar<ScrollMode> for bool
Sourceimpl IntoVar<ScrollRequest> for bool
impl IntoVar<ScrollRequest> for bool
fn into_var(self) -> Var<ScrollRequest>
Sourceimpl IntoVar<ScrollToTarget> for &'static str
impl IntoVar<ScrollToTarget> for &'static str
fn into_var(self) -> Var<ScrollToTarget>
Sourceimpl IntoVar<SideOffsets> for f32
impl IntoVar<SideOffsets> for f32
Sourcefn into_var(self) -> Var<SideOffsets>
fn into_var(self) -> Var<SideOffsets>
All sides equal exact length.
Sourceimpl IntoVar<SideOffsets> for i32
impl IntoVar<SideOffsets> for i32
Sourcefn into_var(self) -> Var<SideOffsets>
fn into_var(self) -> Var<SideOffsets>
All sides equal exact length.
Sourceimpl IntoVar<SmoothScrolling> for (Duration, EasingFn)
impl IntoVar<SmoothScrolling> for (Duration, EasingFn)
fn into_var(self) -> Var<SmoothScrolling>
Sourceimpl IntoVar<SmoothScrolling> for Duration
impl IntoVar<SmoothScrolling> for Duration
Sourcefn into_var(self) -> Var<SmoothScrolling>
fn into_var(self) -> Var<SmoothScrolling>
Linear duration of smooth transition.
Sourceimpl IntoVar<SmoothScrolling> for bool
impl IntoVar<SmoothScrolling> for bool
Sourceimpl IntoVar<TextOverflow> for &'static str
impl IntoVar<TextOverflow> for &'static str
fn into_var(self) -> Var<TextOverflow>
Sourceimpl IntoVar<TextOverflow> for String
impl IntoVar<TextOverflow> for String
fn into_var(self) -> Var<TextOverflow>
Sourceimpl IntoVar<TextOverflow> for bool
impl IntoVar<TextOverflow> for bool
Sourcefn into_var(self) -> Var<TextOverflow>
fn into_var(self) -> Var<TextOverflow>
Truncate (no suffix), or ignore.
Sourceimpl IntoVar<TextOverflow> for char
impl IntoVar<TextOverflow> for char
fn into_var(self) -> Var<TextOverflow>
Sourceimpl IntoVar<TouchActiveConfig> for (Duration, bool)
impl IntoVar<TouchActiveConfig> for (Duration, bool)
fn into_var(self) -> Var<TouchActiveConfig>
Sourceimpl IntoVar<TouchActiveConfig> for Duration
impl IntoVar<TouchActiveConfig> for Duration
fn into_var(self) -> Var<TouchActiveConfig>
Sourceimpl IntoVar<TouchTransformMode> for bool
impl IntoVar<TouchTransformMode> for bool
fn into_var(self) -> Var<TouchTransformMode>
Sourceimpl IntoVar<TreeFilter> for bool
impl IntoVar<TreeFilter> for bool
Sourceimpl IntoVar<Visibility> for bool
impl IntoVar<Visibility> for bool
Sourcefn into_var(self) -> Var<Visibility>
fn into_var(self) -> Var<Visibility>
true->Visiblefalse->Collapsed
Sourceimpl IntoVar<WindowIcon> for &'static [u8]
impl IntoVar<WindowIcon> for &'static [u8]
Sourceimpl IntoVar<WindowIcon> for &Path
impl IntoVar<WindowIcon> for &Path
fn into_var(self) -> Var<WindowIcon>
Sourceimpl IntoVar<WindowIcon> for &str
impl IntoVar<WindowIcon> for &str
Sourcefn into_var(self) -> Var<WindowIcon>
fn into_var(self) -> Var<WindowIcon>
See ImageSource conversion from &str
Sourceimpl IntoVar<WindowIcon> for PathBuf
impl IntoVar<WindowIcon> for PathBuf
fn into_var(self) -> Var<WindowIcon>
Sourceimpl IntoVar<WindowIcon> for String
impl IntoVar<WindowIcon> for String
Sourcefn into_var(self) -> Var<WindowIcon>
fn into_var(self) -> Var<WindowIcon>
Same as conversion from &str.
Sourceimpl<B, R> IntoVar<GradientRadius> for (B, R)
impl<B, R> IntoVar<GradientRadius> for (B, R)
Sourcefn into_var(self) -> Var<GradientRadius>
fn into_var(self) -> Var<GradientRadius>
Ellipse GradientRadiusBase and ellipse radius.
Sourceimpl<C, O> IntoVar<GradientStop> for (C, O)
impl<C, O> IntoVar<GradientStop> for (C, O)
fn into_var(self) -> Var<GradientStop>
Sourceimpl<C, R> IntoVar<GridSpacing> for (C, R)
impl<C, R> IntoVar<GridSpacing> for (C, R)
fn into_var(self) -> Var<GridSpacing>
Sourceimpl<C, S> IntoVar<BorderSide> for (C, S)
impl<C, S> IntoVar<BorderSide> for (C, S)
Sourcefn into_var(self) -> Var<BorderSide>
fn into_var(self) -> Var<BorderSide>
(color, style) side.
Sourceimpl<C, S> IntoVar<BorderSides> for (C, S)
impl<C, S> IntoVar<BorderSides> for (C, S)
Sourcefn into_var(self) -> Var<BorderSides>
fn into_var(self) -> Var<BorderSides>
(color, style) sides.
Sourceimpl<F, const N: usize> IntoVar<AudioSource> for (&[u8; N], F)where
F: Into<AudioDataFormat>,
impl<F, const N: usize> IntoVar<AudioSource> for (&[u8; N], F)where
F: Into<AudioDataFormat>,
Sourcefn into_var(self) -> Var<AudioSource>
fn into_var(self) -> Var<AudioSource>
From encoded data of known format.
Sourceimpl<F, const N: usize> IntoVar<ImageSource> for (&[u8; N], F)where
F: Into<ImageDataFormat>,
impl<F, const N: usize> IntoVar<ImageSource> for (&[u8; N], F)where
F: Into<ImageDataFormat>,
Sourcefn into_var(self) -> Var<ImageSource>
fn into_var(self) -> Var<ImageSource>
From encoded data of known format.
Sourceimpl<F, const N: usize> IntoVar<WindowIcon> for (&[u8; N], F)where
F: Into<ImageDataFormat>,
impl<F, const N: usize> IntoVar<WindowIcon> for (&[u8; N], F)where
F: Into<ImageDataFormat>,
Sourcefn into_var(self) -> Var<WindowIcon>
fn into_var(self) -> Var<WindowIcon>
From encoded data of known format.
Sourceimpl<F> IntoVar<AudioSource> for (&[u8], F)where
F: Into<AudioDataFormat>,
impl<F> IntoVar<AudioSource> for (&[u8], F)where
F: Into<AudioDataFormat>,
Sourcefn into_var(self) -> Var<AudioSource>
fn into_var(self) -> Var<AudioSource>
From encoded data of known format.
Sourceimpl<F> IntoVar<AudioSource> for (IpcBytes, F)where
F: Into<AudioDataFormat>,
impl<F> IntoVar<AudioSource> for (IpcBytes, F)where
F: Into<AudioDataFormat>,
Sourcefn into_var(self) -> Var<AudioSource>
fn into_var(self) -> Var<AudioSource>
From encoded data of known format.
Sourceimpl<F> IntoVar<AudioSource> for (Vec<u8>, F)where
F: Into<AudioDataFormat>,
impl<F> IntoVar<AudioSource> for (Vec<u8>, F)where
F: Into<AudioDataFormat>,
Sourcefn into_var(self) -> Var<AudioSource>
fn into_var(self) -> Var<AudioSource>
From encoded data of known format.
Sourceimpl<F> IntoVar<ImageSource> for (&[u8], F)where
F: Into<ImageDataFormat>,
impl<F> IntoVar<ImageSource> for (&[u8], F)where
F: Into<ImageDataFormat>,
Sourcefn into_var(self) -> Var<ImageSource>
fn into_var(self) -> Var<ImageSource>
From encoded data of known format.
Sourceimpl<F> IntoVar<ImageSource> for (IpcBytes, F)where
F: Into<ImageDataFormat>,
impl<F> IntoVar<ImageSource> for (IpcBytes, F)where
F: Into<ImageDataFormat>,
Sourcefn into_var(self) -> Var<ImageSource>
fn into_var(self) -> Var<ImageSource>
From encoded data of known format.
Sourceimpl<F> IntoVar<ImageSource> for (Vec<u8>, F)where
F: Into<ImageDataFormat>,
impl<F> IntoVar<ImageSource> for (Vec<u8>, F)where
F: Into<ImageDataFormat>,
Sourcefn into_var(self) -> Var<ImageSource>
fn into_var(self) -> Var<ImageSource>
From encoded data of known format.
Sourceimpl<F> IntoVar<SmoothScrolling> for (Duration, F)
impl<F> IntoVar<SmoothScrolling> for (Duration, F)
fn into_var(self) -> Var<SmoothScrolling>
Sourceimpl<F> IntoVar<WindowIcon> for (&[u8], F)where
F: Into<ImageDataFormat>,
impl<F> IntoVar<WindowIcon> for (&[u8], F)where
F: Into<ImageDataFormat>,
Sourcefn into_var(self) -> Var<WindowIcon>
fn into_var(self) -> Var<WindowIcon>
From encoded data of known format.
Sourceimpl<F> IntoVar<WindowIcon> for (IpcBytes, F)where
F: Into<ImageDataFormat>,
impl<F> IntoVar<WindowIcon> for (IpcBytes, F)where
F: Into<ImageDataFormat>,
Sourcefn into_var(self) -> Var<WindowIcon>
fn into_var(self) -> Var<WindowIcon>
From encoded data of known format.
Sourceimpl<F> IntoVar<WindowIcon> for (Vec<u8>, F)where
F: Into<ImageDataFormat>,
impl<F> IntoVar<WindowIcon> for (Vec<u8>, F)where
F: Into<ImageDataFormat>,
Sourcefn into_var(self) -> Var<WindowIcon>
fn into_var(self) -> Var<WindowIcon>
From encoded data of known format.
Sourceimpl<L, const N: usize> IntoVar<GradientStops> for &[(Hsla, L); N]
impl<L, const N: usize> IntoVar<GradientStops> for &[(Hsla, L); N]
Sourcefn into_var(self) -> Var<GradientStops>
fn into_var(self) -> Var<GradientStops>
Sourceimpl<L, const N: usize> IntoVar<GradientStops> for &[(Hsva, L); N]
impl<L, const N: usize> IntoVar<GradientStops> for &[(Hsva, L); N]
Sourcefn into_var(self) -> Var<GradientStops>
fn into_var(self) -> Var<GradientStops>
Sourceimpl<L, const N: usize> IntoVar<GradientStops> for &[(Rgba, L); N]
impl<L, const N: usize> IntoVar<GradientStops> for &[(Rgba, L); N]
Sourcefn into_var(self) -> Var<GradientStops>
fn into_var(self) -> Var<GradientStops>
Sourceimpl<L, const N: usize> IntoVar<GradientStops> for [(Hsla, L); N]
impl<L, const N: usize> IntoVar<GradientStops> for [(Hsla, L); N]
Sourcefn into_var(self) -> Var<GradientStops>
fn into_var(self) -> Var<GradientStops>
Sourceimpl<L, const N: usize> IntoVar<GradientStops> for [(Hsva, L); N]
impl<L, const N: usize> IntoVar<GradientStops> for [(Hsva, L); N]
Sourcefn into_var(self) -> Var<GradientStops>
fn into_var(self) -> Var<GradientStops>
Sourceimpl<L, const N: usize> IntoVar<GradientStops> for [(Rgba, L); N]
impl<L, const N: usize> IntoVar<GradientStops> for [(Rgba, L); N]
Sourcefn into_var(self) -> Var<GradientStops>
fn into_var(self) -> Var<GradientStops>
Sourceimpl<L> IntoVar<GradientStops> for &[(Hsla, L)]
impl<L> IntoVar<GradientStops> for &[(Hsla, L)]
Sourcefn into_var(self) -> Var<GradientStops>
fn into_var(self) -> Var<GradientStops>
Sourceimpl<L> IntoVar<GradientStops> for &[(Hsva, L)]
impl<L> IntoVar<GradientStops> for &[(Hsva, L)]
Sourcefn into_var(self) -> Var<GradientStops>
fn into_var(self) -> Var<GradientStops>
Sourceimpl<L> IntoVar<GradientStops> for &[(Rgba, L)]
impl<L> IntoVar<GradientStops> for &[(Rgba, L)]
Sourcefn into_var(self) -> Var<GradientStops>
fn into_var(self) -> Var<GradientStops>
Sourceimpl<P, O> IntoVar<AnchorOffset> for (P, O)
impl<P, O> IntoVar<AnchorOffset> for (P, O)
Sourcefn into_var(self) -> Var<AnchorOffset>
fn into_var(self) -> Var<AnchorOffset>
(place, origin).
Sourceimpl<P, O> IntoVar<AnchorTransform> for (P, O)
impl<P, O> IntoVar<AnchorTransform> for (P, O)
Sourcefn into_var(self) -> Var<AnchorTransform>
fn into_var(self) -> Var<AnchorTransform>
InnerOffset.
Sourceimpl<P, O> IntoVar<StackDirection> for (P, O)
impl<P, O> IntoVar<StackDirection> for (P, O)
Sourcefn into_var(self) -> Var<StackDirection>
fn into_var(self) -> Var<StackDirection>
New from place and origin, not RTL aware.
Sourceimpl<P, O> IntoVar<StackDirection> for (P, O, bool)
impl<P, O> IntoVar<StackDirection> for (P, O, bool)
Sourcefn into_var(self) -> Var<StackDirection>
fn into_var(self) -> Var<StackDirection>
New from place, origin, and RTL aware flag.
Sourceimpl<S> IntoVar<Indentation> for (S, bool)
impl<S> IntoVar<Indentation> for (S, bool)
fn into_var(self) -> Var<Indentation>
Sourceimpl<T, R, B, L, S> IntoVar<BorderSides> for (T, R, B, L, S)
impl<T, R, B, L, S> IntoVar<BorderSides> for (T, R, B, L, S)
Sourcefn into_var(self) -> Var<BorderSides>
fn into_var(self) -> Var<BorderSides>
(top-color, right-color, bottom-color, left-color, style) sides.
Sourceimpl<T, R, B, L> IntoVar<BorderSides> for (T, R, B, L)
impl<T, R, B, L> IntoVar<BorderSides> for (T, R, B, L)
Sourcefn into_var(self) -> Var<BorderSides>
fn into_var(self) -> Var<BorderSides>
(top, right, bottom, left) sides.
Sourceimpl<T, R, B, L> IntoVar<FactorSideOffsets> for (T, R, B, L)
impl<T, R, B, L> IntoVar<FactorSideOffsets> for (T, R, B, L)
Sourcefn into_var(self) -> Var<FactorSideOffsets>
fn into_var(self) -> Var<FactorSideOffsets>
New top, right, bottom, left.
Sourceimpl<T, R, B, L> IntoVar<SideOffsets> for (T, R, B, L)
impl<T, R, B, L> IntoVar<SideOffsets> for (T, R, B, L)
Sourcefn into_var(self) -> Var<SideOffsets>
fn into_var(self) -> Var<SideOffsets>
(top, right, bottom, left)
Sourceimpl<T, S> IntoVar<AnchorMode> for (T, S)
impl<T, S> IntoVar<AnchorMode> for (T, S)
Sourcefn into_var(self) -> Var<AnchorMode>
fn into_var(self) -> Var<AnchorMode>
Custom transform and size, all else default.
Sourceimpl<TB, LR, S> IntoVar<BorderSides> for (TB, LR, S)
impl<TB, LR, S> IntoVar<BorderSides> for (TB, LR, S)
Sourcefn into_var(self) -> Var<BorderSides>
fn into_var(self) -> Var<BorderSides>
(top-bottom-color, left-right-color, style) sides.
Sourceimpl<TB, LR> IntoVar<BorderRepeats> for (TB, LR)
impl<TB, LR> IntoVar<BorderRepeats> for (TB, LR)
fn into_var(self) -> Var<BorderRepeats>
Sourceimpl<TB, LR> IntoVar<FactorSideOffsets> for (TB, LR)
impl<TB, LR> IntoVar<FactorSideOffsets> for (TB, LR)
Sourcefn into_var(self) -> Var<FactorSideOffsets>
fn into_var(self) -> Var<FactorSideOffsets>
New dimension, top-bottom, left-right.
Sourceimpl<TB, LR> IntoVar<SideOffsets> for (TB, LR)
impl<TB, LR> IntoVar<SideOffsets> for (TB, LR)
Sourcefn into_var(self) -> Var<SideOffsets>
fn into_var(self) -> Var<SideOffsets>
(top-bottom, left-right)
Sourceimpl<TL, TR, BR, BL> IntoVar<CornerRadius> for (TL, TR, BR, BL)
impl<TL, TR, BR, BL> IntoVar<CornerRadius> for (TL, TR, BR, BL)
Sourcefn into_var(self) -> Var<CornerRadius>
fn into_var(self) -> Var<CornerRadius>
(top-left, top-right, bottom-left, bottom-right) corners.