on_enabled

Function on_enabled 

pub fn on_enabled(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&()) -> HandlerResult + Send>,
) -> UiNode
Widget normal interactions now enabled.

Note that this event tracks the actual enabled status of the widget, not the visually enabled status, see Interactivity for more details.

Note that widgets are enabled by default, so this will not notify on init.

See on_enabled_changed for a more general event.

Route

This event property uses a direct route, that is, it cannot be intercepted in parent widgets.