on_enabled_changed

Function on_enabled_changed 

pub fn on_enabled_changed(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&bool) -> HandlerResult + Send>,
) -> UiNode
Widget was enabled or disabled.

Note that this event tracks the actual enabled status of the widget, not the visually enabled status, see Interactivity for more details.

See on_interactivity_changed for a more general interactivity event.

Route

This event property uses a direct route, that is, it cannot be intercepted in parent widgets.