WidgetTreeChangedArgs

Struct WidgetTreeChangedArgs 

pub struct WidgetTreeChangedArgs {
    pub timestamp: DInstant,
    pub prev_tree: WeakWidgetInfoTree,
    pub tree: WidgetInfoTree,
    pub is_update: bool,
    pub propagation: EventPropagationHandle,
}
Fields

timestamp: DInstant

Instant the event happened.

prev_tree: WeakWidgetInfoTree

Previous widget tree.

The strong reference if only held for the duration event update duration, after it is dropped. It will also not upgrade if this event is the first for the window.

This is equal to tree if is_update.

tree: WidgetInfoTree

New widget tree.

is_update: bool

If it is the same tree, just render info updated.

Note that these changes are applied with interior mutability, so the tree shared reference will can be modified on the next render. To compare values save a copy.

Some values updated without tree rebuild are, widget transforms, widget visibility.

propagation: EventPropagationHandle

Propagation handle associated with this event instance.

Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.

Implementations

Source

impl WidgetTreeChangedArgs

pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, prev_tree: impl Into<WeakWidgetInfoTree>, tree: impl Into<WidgetInfoTree>, is_update: impl Into<bool>, ) -> WidgetTreeChangedArgs

New args from values that convert into the argument types.

pub fn now( prev_tree: impl Into<WeakWidgetInfoTree>, tree: impl Into<WidgetInfoTree>, is_update: impl Into<bool>, ) -> WidgetTreeChangedArgs

Arguments for event that happened now (INSTANT.now).