pub enum FrameCaptureMode {
Sporadic,
Next,
NextMask(ImageMaskMode),
All,
AllMask(ImageMaskMode),
}Expand description
Frame image capture mode in a window.
You can set the capture mode using WindowVars::frame_capture_mode.
Variants
Sporadic
Frames are not automatically captured, but you can
use WINDOWS.frame_image to capture frames.
Next
The next rendered frame will be captured and available in FrameImageReadyArgs::frame_image
as a full BGRA8 image.
After the frame is captured the mode changes to Sporadic.
NextMask(ImageMaskMode)
The next rendered frame will be captured and available in FrameImageReadyArgs::frame_image
as an A8 mask image.
After the frame is captured the mode changes to Sporadic.
All
All subsequent frames rendered will be captured and available in FrameImageReadyArgs::frame_image
as full BGRA8 images.
AllMask(ImageMaskMode)
All subsequent frames rendered will be captured and available in FrameImageReadyArgs::frame_image
as A8 mask images.