on_pre_window_changed

Function on_pre_window_changed 

pub fn on_pre_window_changed(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&WindowChangedArgs) -> HandlerResult + Send>,
) -> UiNode
P On window moved, resized or other state changed.

This event aggregates events moves, resizes and other state changes into a single event to simplify tracking composite changes, for example, the window changes size and position when maximized, this can be trivially observed with this event.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.