on_pre_window_close_requested

Function on_pre_window_close_requested 

pub fn on_pre_window_close_requested(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&WindowCloseRequestedArgs) -> HandlerResult + Send>,
) -> UiNode
P On window close requested.

Calling propagation().stop() on this event cancels the window close.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.