on_pre_window_restored

Function on_pre_window_restored 

pub fn on_pre_window_restored(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&WindowChangedArgs) -> HandlerResult + Send>,
) -> UiNode
P On window state changed to WindowState::Normal.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.