pub fn on_pre_window_unminimized(
child: impl IntoUiNode,
handler: Box<dyn FnMut(&WindowChangedArgs) -> HandlerResult + Send>,
) -> UiNodeExpand description
P On window state changed from WindowState::Minimized.
Route
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the
$pn_ident
handlers.