pub fn on_window_load(
child: impl IntoUiNode,
handler: Box<dyn FnMut(&WindowOpenArgs) -> HandlerResult + Send>,
) -> UiNodeExpand description
P On window loaded.
This event notifies once per window, after the first layout and all WindowLoadingHandle
have expired or dropped.
If the window has a renderer this event notifies only after the window is loaded with renderer in the view-process.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.