on_window_state_changed

Function on_window_state_changed 

pub fn on_window_state_changed(
    child: impl IntoUiNode,
    handler: Box<dyn FnMut(&WindowChangedArgs) -> HandlerResult + Send>,
) -> UiNode
P On window state changed.

This event notifies every time the user or the app changes the WindowVars::state.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.