pub struct WindowCapability(/* private fields */);Expand description
Window operations the view-process implements.
Implementations
Sourceimpl WindowCapability
impl WindowCapability
Sourcepub const SET_TITLE: WindowCapability
pub const SET_TITLE: WindowCapability
Can set title text.
Sourcepub const SET_VISIBLE: WindowCapability
pub const SET_VISIBLE: WindowCapability
Can set window visible.
Sourcepub const SET_ALWAYS_ON_TOP: WindowCapability
pub const SET_ALWAYS_ON_TOP: WindowCapability
Can make window “topmost”.
Sourcepub const SET_MOVABLE: WindowCapability
pub const SET_MOVABLE: WindowCapability
Can change if window can be dragged by the user.
Sourcepub const SET_RESIZABLE: WindowCapability
pub const SET_RESIZABLE: WindowCapability
Can change if window can be resized by the user.
Sourcepub const SET_TASKBAR_VISIBLE: WindowCapability
pub const SET_TASKBAR_VISIBLE: WindowCapability
Can make window icon not appear on the taskbar while the window remains visible.
Sourcepub const BRING_TO_TOP: WindowCapability
pub const BRING_TO_TOP: WindowCapability
Can force window to appear in front of other apps, without focusing input.
Sourcepub const SET_ICON: WindowCapability
pub const SET_ICON: WindowCapability
Can set the window icon.
When this is not possible the system specific application metadata icon is used for all windows of the app.
Sourcepub const SET_CURSOR: WindowCapability
pub const SET_CURSOR: WindowCapability
Can set the window cursor to one of the named CursorIcon.
Sourcepub const SET_CURSOR_IMAGE: WindowCapability
pub const SET_CURSOR_IMAGE: WindowCapability
Can set the window cursor to a custom image.
Sourcepub const SET_FOCUS_INDICATOR: WindowCapability
pub const SET_FOCUS_INDICATOR: WindowCapability
Can set attention indicator for the window.
Sourcepub const FOCUS: WindowCapability
pub const FOCUS: WindowCapability
Can focus input on the window.
This is also true if can the system only shows an attention indicator for the window some times.
Sourcepub const DRAG_MOVE: WindowCapability
pub const DRAG_MOVE: WindowCapability
Can initiate a window move operation from a mouse press in the content area.
Sourcepub const DRAG_RESIZE: WindowCapability
pub const DRAG_RESIZE: WindowCapability
Can initiate a window resize operation from a mouse press in the content area.
Sourcepub const OPEN_TITLE_BAR_CONTEXT_MENU: WindowCapability
pub const OPEN_TITLE_BAR_CONTEXT_MENU: WindowCapability
Can open the system context menu that usually shows on right click on the title bar.
Sourcepub const SYSTEM_CHROME: WindowCapability
pub const SYSTEM_CHROME: WindowCapability
If operating system provides a window chrome (title bar, resize borders).
Sourcepub const MINIMIZE: WindowCapability
pub const MINIMIZE: WindowCapability
Can minimize window.
Sourcepub const RESTORE: WindowCapability
pub const RESTORE: WindowCapability
Can restore window to normal.
Sourcepub const MAXIMIZE: WindowCapability
pub const MAXIMIZE: WindowCapability
Can maximize window.
Sourcepub const FULLSCREEN: WindowCapability
pub const FULLSCREEN: WindowCapability
Can make window fullscreen.
Sourcepub const EXCLUSIVE: WindowCapability
pub const EXCLUSIVE: WindowCapability
Can takeover video output to show only the window content.
Sourcepub const SET_CHROME: WindowCapability
pub const SET_CHROME: WindowCapability
Can toggle if the system chrome (title bar, resize border) is visible.
Sourcepub const SET_POSITION: WindowCapability
pub const SET_POSITION: WindowCapability
Can programmatically move window after it is open.
Sourcepub const SET_SIZE: WindowCapability
pub const SET_SIZE: WindowCapability
Can programmatically resize window after it is open.
Sourcepub const DISABLE_CLOSE_BUTTON: WindowCapability
pub const DISABLE_CLOSE_BUTTON: WindowCapability
Can disable close button.
Sourcepub const DISABLE_MINIMIZE_BUTTON: WindowCapability
pub const DISABLE_MINIMIZE_BUTTON: WindowCapability
Can disable minimize button.
Sourcepub const DISABLE_MAXIMIZE_BUTTON: WindowCapability
pub const DISABLE_MAXIMIZE_BUTTON: WindowCapability
Can disable maximize button.
Sourcepub const SET_SYSTEM_SHUTDOWN_WARN: WindowCapability
pub const SET_SYSTEM_SHUTDOWN_WARN: WindowCapability
Can set a system shutdown warning/blocker associated with the window.
Sourcepub const SET_IME_AREA: WindowCapability
pub const SET_IME_AREA: WindowCapability
Can set the IME area, show virtual keyboard.
Sourceimpl WindowCapability
impl WindowCapability
Sourcepub const fn empty() -> WindowCapability
pub const fn empty() -> WindowCapability
Get a flags value with all bits unset.
Sourcepub const fn all() -> WindowCapability
pub const fn all() -> WindowCapability
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<WindowCapability>
pub const fn from_bits(bits: u64) -> Option<WindowCapability>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> WindowCapability
pub const fn from_bits_truncate(bits: u64) -> WindowCapability
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> WindowCapability
pub const fn from_bits_retain(bits: u64) -> WindowCapability
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<WindowCapability>
pub fn from_name(name: &str) -> Option<WindowCapability>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: WindowCapability) -> bool
pub const fn intersects(&self, other: WindowCapability) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: WindowCapability) -> bool
pub const fn contains(&self, other: WindowCapability) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: WindowCapability)
pub fn insert(&mut self, other: WindowCapability)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: WindowCapability)
pub fn remove(&mut self, other: WindowCapability)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: WindowCapability)
pub fn toggle(&mut self, other: WindowCapability)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: WindowCapability, value: bool)
pub fn set(&mut self, other: WindowCapability, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: WindowCapability) -> WindowCapability
pub const fn intersection(self, other: WindowCapability) -> WindowCapability
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: WindowCapability) -> WindowCapability
pub const fn union(self, other: WindowCapability) -> WindowCapability
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: WindowCapability) -> WindowCapability
pub const fn difference(self, other: WindowCapability) -> WindowCapability
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: WindowCapability,
) -> WindowCapability
pub const fn symmetric_difference( self, other: WindowCapability, ) -> WindowCapability
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> WindowCapability
pub const fn complement(self) -> WindowCapability
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl WindowCapability
impl WindowCapability
Sourcepub const fn iter(&self) -> Iter<WindowCapability>
pub const fn iter(&self) -> Iter<WindowCapability>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<WindowCapability>
pub const fn iter_names(&self) -> IterNames<WindowCapability>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.