pub struct WindowCloseRequestedArgs {
pub timestamp: DInstant,
pub windows: IdSet<WindowId>,
pub propagation: EventPropagationHandle,
}Expand description
WINDOW_CLOSE_REQUESTED_EVENT args.
Requesting propagation().stop() on this event cancels the window close.
Fields
timestamp: DInstantInstant the event happened.
windows: IdSet<WindowId>Windows closing, headed and headless.
This is at least one window, is multiple if the close operation was requested as group, cancelling the request cancels close for all windows.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl WindowCloseRequestedArgs
impl WindowCloseRequestedArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
windows: impl Into<IdSet<WindowId>>,
) -> WindowCloseRequestedArgs
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, windows: impl Into<IdSet<WindowId>>, ) -> WindowCloseRequestedArgs
New args from values that convert into the argument types.