#[non_exhaustive]pub struct Page {
pub title: VarEq<Txt>,
pub info: VarEq<Txt>,
pub header: WidgetFn<PageArgs>,
pub side: WidgetFn<PageArgs>,
pub content: WidgetFn<PageArgs>,
pub footer: WidgetFn<PageArgs>,
pub skip: VarEq<bool>,
pub can_back: VarEq<bool>,
pub can_next: VarEq<bool>,
}Expand description
Represents a page builder for Wizard!.
The widgets defined here must represent only the content that is unique for each page,
the wizard widget has properties that define the wizard parts, for example, if the side
has an image that is the same for all pages it is defined in Wizard::side_fn.
The builders care called in the parent Wizard! widget context.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.title: VarEq<Txt>Page title.
The default header presents this for the selected page.
info: VarEq<Txt>Page info.
This is a short explanation about the page. Supports basic markdown span formatting.
The default header presents this for the selected page.
header: WidgetFn<PageArgs>Page header content.
Presents the title, info and any other custom header detail
when the page is selected.
The header of each page is wrapped by Wizard::header_fn to form the full header.
If this builds UiNode::nil the header panel is collapsed for this page.
Is default_page_header by default.
side: WidgetFn<PageArgs>Page side panel content.
The side content of each page is wrapped by Wizard::side_fn to form the full side panel.
If this is a list node the wizard side builder will generate a layout panel for the items.
If this builds UiNode::nil the side panel is collapsed for this page. An empty list node
signals the side builder that it should be visible without page content.
Is default_page_side by default.
content: WidgetFn<PageArgs>Page main content.
The main content of each page is wrapped by Wizard::content_fn to form the full content panel.
Page footer content.
The footer of each page is wrapped by Wizard::footer_fn to form the full footer panel.
If this is a list node the wizard footer builder will generate a layout panel for the items.
Is default_page_footer by default.
skip: VarEq<bool>When true the page is skipped over.
Is false by default.
can_back: VarEq<bool>When is not the first page controls the wizard BACK_CMD handle.
Is true by default.
can_next: VarEq<bool>When is not the last page controls the wizard NEXT_CMD handle.
Implementations