#[non_exhaustive]pub struct SideFnArgs {
pub side: UiNode,
pub side_extra: UiNode,
pub background: UiNode,
pub index: usize,
pub pages_len: usize,
}Expand description
Arguments for a wizard side container builder.
See SIDE_FN_VAR for more details.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.side: UiNodePage side content.
This is the Page::side instance.
This is never UiNode::nil as that is handled by Wizard!.
This can be UiNode::is_list, in this case a layout panel must be generated for
the items, usually a vertical stack aligned to Align::BOTTOM.
side_extra: UiNodeExtra side content that is the same for all pages.
This is the side_extra_fn instance.
This can be UiNode::nil if no extra content is defined, otherwise it is
like side a list or a single node, usually presented under the side list,
with a separator.
background: UiNodeBackground visual.
This is the SIDE_BACKGROUND_FN_VAR instance.
index: usizePage index on the pages list.
Is usize::MAX if the page is a custom assign to WIZARD::selected_page that is not on the list.
pages_len: usizeCount of pages on the list.
Implementations