Wizard

Struct Wizard 

pub struct Wizard(/* private fields */);
W Paginated widget that

Implementations

Source

impl Wizard

pub fn header_fn(&self, wgt_fn: impl IntoVar<WidgetFn<HeaderFnArgs>>)

P Widget function that converts a HeaderFnArgs into a page header container widget.

This property sets the HEADER_FN_VAR.

Source

impl Wizard

pub fn header_background_fn(&self, wgt_fn: impl IntoVar<WidgetFn<()>>)

P Widget function that makes a background visual for the page header container widget.

This property sets the HEADER_BACKGROUND_FN_VAR.

Source

impl Wizard

pub fn side_fn(&self, wgt_fn: impl IntoVar<WidgetFn<SideFnArgs>>)

P Widget function that converts a SideFnArgs into a page side container widget.

This property sets the SIDE_FN_VAR.

Source

impl Wizard

pub fn side_background_fn(&self, wgt_fn: impl IntoVar<WidgetFn<()>>)

P Widget function that makes a background visual for the page side container widget.

This property sets the SIDE_BACKGROUND_FN_VAR.

Source

impl Wizard

pub fn side_extra_fn(&self, side_extra_fn: impl IntoVar<WidgetFn<PageArgs>>)

P Widget function that converts PageArgs to extra side panel content.

Note that this extra content will only instantiate if the Page::side does not instantiate nil.

This property sets the SIDE_EXTRA_FN_VAR.

Source

impl Wizard

pub fn content_fn(&self, wgt_fn: impl IntoVar<WidgetFn<ContentFnArgs>>)

P Widget function that converts a ContentFnArgs into a page main content container container widget.

This property sets the CONTENT_FN_VAR.

Source

impl Wizard

pub fn footer_fn(&self, wgt_fn: impl IntoVar<WidgetFn<FooterFnArgs>>)

P Widget function that converts a FooterFnArgs into a page side container widget.

This property sets the FOOTER_FN_VAR.

Source

impl Wizard

pub fn footer_extra_fn(&self, footer_extra_fn: impl IntoVar<WidgetFn<PageArgs>>)

P Widget function that converts PageArgs to extra footer content.

This property sets the FOOTER_EXTRA_FN_VAR.

Source

impl Wizard

pub fn panel_fn(&self, wgt_fn: impl IntoVar<WidgetFn<PanelFnArgs>>)

P Widget function that converts a PanelFnArgs into a wizard.

This property sets the PANEL_FN_VAR.

Source

impl Wizard

pub fn widget_new() -> Wizard

Start building a new instance.

pub fn widget_type() -> WidgetType

Gets the widget type info.

Source

impl Wizard

pub fn pages(&self, pages: impl IntoVar<Vec<Page>>)

B Defines the wizard pages.

Pages are built on demand, the Page value defines wgt_fn! builders that are used by wizard when the page needs to be instantiated.

Source

impl Wizard

pub fn get_title(&self, title: impl IntoVar<Txt>)

P Get the current page title.

Source

impl Wizard

pub fn can_cancel(&self, enabled: impl IntoVar<bool>)

P Defines if on_cancel and on_pre_cancel command handlers are enabled in the widget and descendants.

Sets the CAN_CANCEL_VAR.

Source

impl Wizard

pub fn on_cancel( &self, handler: Box<dyn FnMut(&CommandArgs) -> HandlerResult + Send>, )

P Wizard cancel requested.

Command

This property will subscribe to the CANCEL_CMD command scoped on the widget. If set on the Window! root widget it will also subscribe to the command scoped on the window.

The command handle is enabled by default and can be disabled using the contextual property can_cancel .

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.

Source

impl Wizard

pub fn on_pre_cancel( &self, handler: Box<dyn FnMut(&CommandArgs) -> HandlerResult + Send>, )

P Wizard cancel requested.

Command

This property will subscribe to the CANCEL_CMD command scoped on the widget. If set on the Window! root widget it will also subscribe to the command scoped on the window.

The command handle is enabled by default and can be disabled using the contextual property can_cancel .

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.

Source

impl Wizard

pub fn can_finish(&self, enabled: impl IntoVar<bool>)

P Defines if on_finish and on_pre_finish command handlers are enabled in the widget and descendants.

Sets the CAN_FINISH_VAR.

Source

impl Wizard

pub fn on_finish( &self, handler: Box<dyn FnMut(&CommandArgs) -> HandlerResult + Send>, )

P Wizard finish requested.

Command

This property will subscribe to the FINISH_CMD command scoped on the widget. If set on the Window! root widget it will also subscribe to the command scoped on the window.

The command handle is enabled by default and can be disabled using the contextual property can_finish .

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.

Source

impl Wizard

pub fn on_pre_finish( &self, handler: Box<dyn FnMut(&CommandArgs) -> HandlerResult + Send>, )

P Wizard finish requested.

Command

This property will subscribe to the FINISH_CMD command scoped on the widget. If set on the Window! root widget it will also subscribe to the command scoped on the window.

The command handle is enabled by default and can be disabled using the contextual property can_finish .

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.

Source

impl Wizard

pub fn finish_cmd_name(&self, name: impl IntoVar<Txt>)

P Set the name for the FINISH_CMD scoped on this widget.

Methods from Deref<Target = WidgetBase>

pub fn widget_builder(&mut self) -> &mut WidgetBuilder

Returns a mutable reference to the widget builder.

pub fn widget_when(&mut self) -> Option<&mut WhenInfo>

Returns a mutable reference to the when block if called inside a when block.

pub fn widget_take(&mut self) -> WidgetBuilder

Takes the widget builder, finishing the widget macro build.

After this call trying to set a property using self will panic, the returned builder can still be manipulated directly.

pub fn widget_build(&mut self) -> UiNode

Build the widget.

After this call trying to set a property will panic.

pub fn widget_importance(&mut self) -> &mut Importance

Returns a mutable reference to the importance of the next property assigns, unsets or when blocks.

Note that during the widget_intrinsic call this is Importance::WIDGET and after it is Importance::INSTANCE.

pub fn start_when_block( &mut self, inputs: Box<[WhenInput]>, state: Var<bool>, expr: &'static str, location: SourceLocation, )

Start building a when block, all properties set after this call are pushed in the when block.

pub fn end_when_block(&mut self)

End the current when block, all properties set after this call are pushed in the widget.

pub fn id(&self, id: impl IntoValue<WidgetId>)

B Unique ID of the widget instance.

Note that the id can convert from a &'static str unique name.