pub fn on_access_scroll(
child: impl IntoUiNode,
handler: Box<dyn FnMut(&AccessScrollArgs) -> HandlerResult + Send>,
) -> UiNodeExpand description
Access requested a scroll command.
Note that the scroll widget already handles this event.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.