#[non_exhaustive]pub struct AudioMix { /* private fields */ }Expand description
Represents an audio source.
Audio is defined by layers, each subsequent layer applies to the computed result of the previous layer.
Implementations
Sourceimpl AudioMix
impl AudioMix
Sourcepub fn with_delay(self, duration: Duration) -> AudioMix
pub fn with_delay(self, duration: Duration) -> AudioMix
Plays silence for the duration before starting layers mix.
Sourcepub fn with_total_duration(self, duration: Duration) -> AudioMix
pub fn with_total_duration(self, duration: Duration) -> AudioMix
Set the total duration.
If not set audio plays until all audio and mix layers end. If set audio plays for the duration, if layers end before the duration plays silent at the end, if layers exceed the duration they are clipped.
Note that the duration must account for the initial delay, the initial silence is included in the the total duration.
Sourcepub fn with_audio(self, audio: &AudioTrack) -> AudioMix
pub fn with_audio(self, audio: &AudioTrack) -> AudioMix
Add layer that plays the cached audio.
The audio samples are adapted to the output format and each sample added to the under layers result.
Sourcepub fn with_audio_clip(
self,
audio: &AudioTrack,
skip: Duration,
take: Duration,
) -> AudioMix
pub fn with_audio_clip( self, audio: &AudioTrack, skip: Duration, take: Duration, ) -> AudioMix
Add layer that clips and plays the cached audio.
This is similar to with_audio, but only the range skip..skip + take is played.
Sourcepub fn with_mix(self, mix: impl Into<AudioMix>) -> AudioMix
pub fn with_mix(self, mix: impl Into<AudioMix>) -> AudioMix
Add layer that plays another mix.
The inner mix is sampled as computed audio, that is, samples are computed first and added to the under layers result.
Sourcepub fn with_mix_clip(
self,
mix: impl Into<AudioMix>,
skip: Duration,
take: Duration,
) -> AudioMix
pub fn with_mix_clip( self, mix: impl Into<AudioMix>, skip: Duration, take: Duration, ) -> AudioMix
Add layer that clips and plays another mix.
This is similar to with_mix, but only the range skip..skip + take is played.
Sourcepub fn with_sine_wave(self, frequency: f32, duration: Duration) -> AudioMix
pub fn with_sine_wave(self, frequency: f32, duration: Duration) -> AudioMix
Add layer that generates a sine wave sound.
The generated sound samples are added to the under layers result.
Sourcepub fn with_volume_linear(
self,
start: Duration,
duration: Duration,
start_volume: Factor,
end_volume: Factor,
) -> AudioMix
pub fn with_volume_linear( self, start: Duration, duration: Duration, start_volume: Factor, end_volume: Factor, ) -> AudioMix
Add effect layer that applies a linear volume transition.
When the playback is in range the computed sample of under layers is multiplied by the linear interpolation
between start_volume and end_volume.
Note that outside the volume range is not affected, before and after.
Sourcepub fn with_fade_in(self, transition_duration: Duration) -> AudioMix
pub fn with_fade_in(self, transition_duration: Duration) -> AudioMix
Add an effect layer that fades in from the start over a transition duration.
A linear volume transition at the start raises the volume of under layers from zero to normal over the transition_duration.
Sourcepub fn with_fade_out(
self,
start: Duration,
transition_duration: Duration,
) -> AudioMix
pub fn with_fade_out( self, start: Duration, transition_duration: Duration, ) -> AudioMix
Add an effect layer that fades out the audio after start.
A linear volume transition lowers the volume of under layers after start to zero over transition_duration,
the volume remains zeroed until audio end.
Note that this does not affect the total duration, you must also call with_total_duration to fade out and stop.