pub fn on_pre_paste(
child: impl IntoUiNode,
handler: Box<dyn FnMut(&CommandArgs) -> HandlerResult + Send>,
) -> UiNodeExpand description
P On paste command.
Receives PASTE_CMD command events scoped on the widget. You can use the CLIPBOARD service
to receive data from the clipboard.
Command
This property will subscribe to the
PASTE_CMD
command scoped on the widget. If set on the Window! root widget it will also subscribe to
the command scoped on the window.
The command handle is enabled by default and can be disabled using the contextual property
can_paste
.
Route
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the
$pn_ident
handlers.