pub struct CommandArgs {
pub timestamp: DInstant,
pub param: Option<CommandParam>,
pub scope: CommandScope,
pub target: Option<WidgetPath>,
pub enabled: bool,
pub propagation: EventPropagationHandle,
}Expand description
Event args for command events.
Fields
timestamp: DInstantInstant the event happened.
param: Option<CommandParam>Optional parameter for the command handler.
scope: CommandScopeScope of command that notified.
target: Option<WidgetPath>Target widget.
- If the scope is
Appthis isNone. - If the scope is
Windowthis is the window root widget, if the window was found. - If the scope is
Widgetthis is the widget, if it was found.
enabled: boolIf the command was enabled when the command notified.
If false the command primary action must not run, but a secondary “disabled interaction”
that indicates what conditions enable the command is recommended.
Note that this is the Command::is_enabled value, it is true id any handle is enabled,
the local handler might still be disabled.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl CommandArgs
impl CommandArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
param: impl Into<Option<CommandParam>>,
scope: impl Into<CommandScope>,
target: impl Into<Option<WidgetPath>>,
enabled: impl Into<bool>,
) -> CommandArgs
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, param: impl Into<Option<CommandParam>>, scope: impl Into<CommandScope>, target: impl Into<Option<WidgetPath>>, enabled: impl Into<bool>, ) -> CommandArgs
Sourcepub fn try_new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
param: impl Into<Option<CommandParam>>,
scope: impl Into<CommandScope>,
target: impl Into<Option<WidgetPath>>,
enabled: impl Into<bool>,
) -> Result<CommandArgs, Txt>
pub fn try_new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, param: impl Into<Option<CommandParam>>, scope: impl Into<CommandScope>, target: impl Into<Option<WidgetPath>>, enabled: impl Into<bool>, ) -> Result<CommandArgs, Txt>
New args from values that convert into the argument types.
Returns an error if the constructed arguments are invalid.
Sourcepub fn now(
param: impl Into<Option<CommandParam>>,
scope: impl Into<CommandScope>,
target: impl Into<Option<WidgetPath>>,
enabled: impl Into<bool>,
) -> CommandArgs
pub fn now( param: impl Into<Option<CommandParam>>, scope: impl Into<CommandScope>, target: impl Into<Option<WidgetPath>>, enabled: impl Into<bool>, ) -> CommandArgs
Sourcepub fn try_now(
param: impl Into<Option<CommandParam>>,
scope: impl Into<CommandScope>,
target: impl Into<Option<WidgetPath>>,
enabled: impl Into<bool>,
) -> Result<CommandArgs, Txt>
pub fn try_now( param: impl Into<Option<CommandParam>>, scope: impl Into<CommandScope>, target: impl Into<Option<WidgetPath>>, enabled: impl Into<bool>, ) -> Result<CommandArgs, Txt>
Arguments for event that happened now (INSTANT.now).
Returns an error if the constructed arguments are invalid.
Sourcepub fn assert_valid(&self)
pub fn assert_valid(&self)
Panics if the arguments are invalid.
Sourceimpl CommandArgs
impl CommandArgs
Sourcepub fn param<T>(&self) -> Option<&T>where
T: Any,
pub fn param<T>(&self) -> Option<&T>where
T: Any,
Returns a reference to a parameter of T if parameter is set to a value of T.
Sourcepub fn scope_matches(&self, direct_only: bool, scope: CommandScope) -> bool
pub fn scope_matches(&self, direct_only: bool, scope: CommandScope) -> bool
If direct_only is enabled only matches exact command scope matches,
otherwise the app scope matches all args, the window scope matches all events for the window
or widgets in the window and the widget scope matches the widget and all descendants.