pub struct CommandHandle { /* private fields */ }Expand description
A handle to a Command subscription.
Holding the command handle indicates that the command is relevant in the current app state. The handle also needs to be enabled to indicate that the command primary action can be executed.
You can use the Command::subscribe method in a command type to create a handle.
Implementations
Sourceimpl CommandHandle
impl CommandHandle
Sourcepub fn enabled(&self) -> &Var<bool>
pub fn enabled(&self) -> &Var<bool>
Variable that gets and sets if this specific handle is enabled.
The Command::is_enabled is true if any handle is enabled.
Sourcepub fn dummy() -> CommandHandle
pub fn dummy() -> CommandHandle
New handle not connected to any command.