pub struct ReturnFocusChangedArgs {
pub timestamp: DInstant,
pub scope: Option<InteractionPath>,
pub prev_return: Option<InteractionPath>,
pub new_return: Option<InteractionPath>,
pub propagation: EventPropagationHandle,
}Expand description
RETURN_FOCUS_CHANGED_EVENT arguments.
Fields
timestamp: DInstantInstant the event happened.
scope: Option<InteractionPath>The scope that returns the focus when focused directly.
Is None if the previous focus was the return focus of a scope that was removed.
prev_return: Option<InteractionPath>Previous return focus of the widget.
new_return: Option<InteractionPath>New return focus of the widget.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl ReturnFocusChangedArgs
impl ReturnFocusChangedArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
scope: impl Into<Option<InteractionPath>>,
prev_return: impl Into<Option<InteractionPath>>,
new_return: impl Into<Option<InteractionPath>>,
) -> ReturnFocusChangedArgs
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, scope: impl Into<Option<InteractionPath>>, prev_return: impl Into<Option<InteractionPath>>, new_return: impl Into<Option<InteractionPath>>, ) -> ReturnFocusChangedArgs
New args from values that convert into the argument types.
Sourcepub fn now(
scope: impl Into<Option<InteractionPath>>,
prev_return: impl Into<Option<InteractionPath>>,
new_return: impl Into<Option<InteractionPath>>,
) -> ReturnFocusChangedArgs
pub fn now( scope: impl Into<Option<InteractionPath>>, prev_return: impl Into<Option<InteractionPath>>, new_return: impl Into<Option<InteractionPath>>, ) -> ReturnFocusChangedArgs
Arguments for event that happened now (INSTANT.now).
Sourceimpl ReturnFocusChangedArgs
impl ReturnFocusChangedArgs
Sourcepub fn is_widget_move(&self) -> bool
pub fn is_widget_move(&self) -> bool
If the return focus is the same widget but the widget path changed and the widget is still in the same focus scope.
Sourcepub fn is_alt_return(&self) -> bool
pub fn is_alt_return(&self) -> bool
If scope is an ALT scope and prev_return or new_return if the
widget outside the scope that will be focused back when the user escapes the ALT scope.
Sourcepub fn lost_return_focus(&self, widget_id: WidgetId) -> bool
pub fn lost_return_focus(&self, widget_id: WidgetId) -> bool
if the widget was in the prev_return and is not in the new_return.
Sourcepub fn got_return_focus(&self, widget_id: WidgetId) -> bool
pub fn got_return_focus(&self, widget_id: WidgetId) -> bool
if the widget was not in the prev_return and is in the new_return.
Sourcepub fn was_return_focus(&self, widget_id: WidgetId) -> bool
pub fn was_return_focus(&self, widget_id: WidgetId) -> bool
if the widget was the prev_return and is the new_return.
Sourcepub fn is_return_focus(&self, widget_id: WidgetId) -> bool
pub fn is_return_focus(&self, widget_id: WidgetId) -> bool
if the widget was not the prev_return and is the new_return.
Sourcepub fn is_return_focus_enter(&self, widget_id: WidgetId) -> bool
pub fn is_return_focus_enter(&self, widget_id: WidgetId) -> bool
If widget_id is the new return focus or a parent of the new return and was not a parent of the previous return.
Sourcepub fn is_return_focus_leave(&self, widget_id: WidgetId) -> bool
pub fn is_return_focus_leave(&self, widget_id: WidgetId) -> bool
If widget_id is the previous return focus or a parent of the previous return and is not a parent of the new return.