pub fn on_pre_click(
child: impl IntoUiNode,
handler: Box<dyn FnMut(&ClickArgs) -> HandlerResult + Send>,
) -> UiNodeExpand description
P On widget click with the primary button and any click count and the widget is enabled.
This raises only if the click is primary, but raises for any click count (double/triple clicks).
Use on_any_click to handle clicks from any button or on_single_click to not include
double/triple clicks.
Route
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the
$pn_ident
handlers.