pub struct MouseMoveArgs {
pub timestamp: DInstant,
pub window_id: WindowId,
pub device_id: InputDeviceId,
pub modifiers: ModifiersState,
pub coalesced_pos: Vec<Point2D<Dip, Dip>>,
pub position: Point2D<Dip, Dip>,
pub hits: HitTestInfo,
pub target: InteractionPath,
pub capture: Option<CaptureInfo>,
pub propagation: EventPropagationHandle,
}Expand description
MOUSE_MOVE_EVENT arguments.
Fields
timestamp: DInstantInstant the event happened.
window_id: WindowIdId of window that received the event.
device_id: InputDeviceIdId of device that generated the event.
modifiers: ModifiersStateWhat modifier keys where pressed when this event happened.
coalesced_pos: Vec<Point2D<Dip, Dip>>Positions of the cursor in between the previous event and this one.
Mouse move events can be coalesced, i.e. multiple moves packed into a single event.
position: Point2D<Dip, Dip>Position of the mouse in the window’s content area.
hits: HitTestInfoHit-test result for the mouse point in the window.
target: InteractionPathFull path to the top-most hit in hits.
capture: Option<CaptureInfo>Current pointer capture.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl MouseMoveArgs
impl MouseMoveArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
window_id: impl Into<WindowId>,
device_id: impl Into<InputDeviceId>,
modifiers: impl Into<ModifiersState>,
coalesced_pos: impl Into<Vec<Point2D<Dip, Dip>>>,
position: impl Into<Point2D<Dip, Dip>>,
hits: impl Into<HitTestInfo>,
target: impl Into<InteractionPath>,
capture: impl Into<Option<CaptureInfo>>,
) -> MouseMoveArgs
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, window_id: impl Into<WindowId>, device_id: impl Into<InputDeviceId>, modifiers: impl Into<ModifiersState>, coalesced_pos: impl Into<Vec<Point2D<Dip, Dip>>>, position: impl Into<Point2D<Dip, Dip>>, hits: impl Into<HitTestInfo>, target: impl Into<InteractionPath>, capture: impl Into<Option<CaptureInfo>>, ) -> MouseMoveArgs
New args from values that convert into the argument types.
Sourcepub fn now(
window_id: impl Into<WindowId>,
device_id: impl Into<InputDeviceId>,
modifiers: impl Into<ModifiersState>,
coalesced_pos: impl Into<Vec<Point2D<Dip, Dip>>>,
position: impl Into<Point2D<Dip, Dip>>,
hits: impl Into<HitTestInfo>,
target: impl Into<InteractionPath>,
capture: impl Into<Option<CaptureInfo>>,
) -> MouseMoveArgs
pub fn now( window_id: impl Into<WindowId>, device_id: impl Into<InputDeviceId>, modifiers: impl Into<ModifiersState>, coalesced_pos: impl Into<Vec<Point2D<Dip, Dip>>>, position: impl Into<Point2D<Dip, Dip>>, hits: impl Into<HitTestInfo>, target: impl Into<InteractionPath>, capture: impl Into<Option<CaptureInfo>>, ) -> MouseMoveArgs
Arguments for event that happened now (INSTANT.now).