pub fn on_pointer_capture_changed(
child: impl IntoUiNode,
handler: Box<dyn FnMut(&PointerCaptureArgs) -> HandlerResult + Send>,
) -> UiNodeExpand description
P Widget acquired or lost mouse and touch capture.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.