#[non_exhaustive]pub struct SfxDataInfo {
pub name: Txt,
pub exact_len: Option<u64>,
}Expand description
Represents a data entry that can be served from a SfxClient.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: TxtName.
exact_len: Option<u64>Exact data length, if it is known.
This is None if the data is decompressing from a custom zstd
file that does not define “contentsize”.