pub trait CommandUndoExt {
// Required methods
fn undo_scoped(self) -> Var<Command>;
fn undo_stack(self) -> UndoStackInfo;
fn redo_stack(self) -> UndoStackInfo;
}Expand description
Undo extension methods for commands.
Required Methods
Sourcefn undo_scoped(self) -> Var<Command>
fn undo_scoped(self) -> Var<Command>
Gets the command scoped to the undo scope widget that is (or contains) the focused widget. If no undo scope is focused gets the command scoped on the app.
Sourcefn undo_stack(self) -> UndoStackInfo
fn undo_stack(self) -> UndoStackInfo
Latest undo stack for the given scope, same as calling UNDO::undo_stack inside the scope.
Sourcefn redo_stack(self) -> UndoStackInfo
fn redo_stack(self) -> UndoStackInfo
Latest undo stack for the given scope, same as calling UNDO::redo_stack inside the scope.