pub struct WidgetUpdates { /* private fields */ }Expand description
Widget updates of the current cycle.
Most information about the current update is provided by the UPDATES service. Variable and event instances
are also flagged new inside the update context.
This type contains only the delivery_list, widget nodes must use it to skip the widget branch, other nodes
need only pass the reference to all children nodes.
Widgets can extend the current update to descendant widgets using the clone_insert* methods, but this is only recommended
if the descendant nodes know to support this, usually gated by a contextual flag, event updates need to be received differently for example,
as the event target will not contain the inserted widget.
Implementations
Sourceimpl WidgetUpdates
impl WidgetUpdates
Sourcepub fn new(delivery_list: UpdateDeliveryList) -> WidgetUpdates
pub fn new(delivery_list: UpdateDeliveryList) -> WidgetUpdates
New with list.
Sourcepub fn delivery_list(&self) -> &UpdateDeliveryList
pub fn delivery_list(&self) -> &UpdateDeliveryList
Updates delivery list.
Sourcepub fn delivery_list_mut(&mut self) -> &mut UpdateDeliveryList
pub fn delivery_list_mut(&mut self) -> &mut UpdateDeliveryList
Updates delivery list.
Sourcepub fn with_window<H, R>(&self, handle: H) -> Option<R>where
H: FnOnce() -> R,
pub fn with_window<H, R>(&self, handle: H) -> Option<R>where
H: FnOnce() -> R,
Calls handle if update was requested for the WINDOW.
Sourcepub fn with_widget<H, R>(&self, handle: H) -> Option<R>where
H: FnOnce() -> R,
pub fn with_widget<H, R>(&self, handle: H) -> Option<R>where
H: FnOnce() -> R,
Calls handle if update was requested for the WIDGET.
Sourcepub fn extend(&mut self, other: WidgetUpdates)
pub fn extend(&mut self, other: WidgetUpdates)
Copy all delivery from other onto self.
Sourcepub fn clone_insert_wgt(
&self,
wgt: impl WidgetPathProvider,
) -> Cow<'_, WidgetUpdates>
pub fn clone_insert_wgt( &self, wgt: impl WidgetPathProvider, ) -> Cow<'_, WidgetUpdates>
If the delivery list does not contain the wgt clones the updates and inserts the widget.
If the list already contains the widget returns the reference.
Sourcepub fn clone_insert_all<W>(
&self,
widgets: impl IntoIterator<Item = W>,
) -> Cow<'_, WidgetUpdates>where
W: WidgetPathProvider,
pub fn clone_insert_all<W>(
&self,
widgets: impl IntoIterator<Item = W>,
) -> Cow<'_, WidgetUpdates>where
W: WidgetPathProvider,
If the delivery list does not contain all widgets clones the updates and inserts all widgets.
If the list already contains all widgets returns the reference.
Sourcepub fn clone_insert_any<W>(
&self,
widgets: impl IntoIterator<Item = W>,
) -> Cow<'_, WidgetUpdates>where
W: WidgetPathProvider,
pub fn clone_insert_any<W>(
&self,
widgets: impl IntoIterator<Item = W>,
) -> Cow<'_, WidgetUpdates>where
W: WidgetPathProvider,
If the delivery list does not contain any widgets clones the updates and inserts the last widget.
If the list already contains at least one widget returns the reference.