pub struct Bezier { /* private fields */ }Expand description
A unit cubic Bézier curve, used for timing functions in CSS transitions and animations.
Implementations
Sourceimpl Bezier
impl Bezier
Sourcepub fn new(x1: f32, y1: f32, x2: f32, y2: f32) -> Bezier
pub fn new(x1: f32, y1: f32, x2: f32, y2: f32) -> Bezier
Create a unit cubic Bézier curve from the two middle control points.
X coordinate is time, Y coordinate is function advancement. The nominal range for both is 0 to 1.
The start and end points are always (0, 0) and (1, 1) so that a transition or animation starts at 0% and ends at 100%.