pub struct WeakEq<T>(pub Weak<T>)
where
T: Send + Sync;Expand description
An std::sync::Weak value that implements equality by pointer comparison.
This type allows external types that are only Send + Sync to become
a full VarValue to be allowed as a variable value.
Tuple Fields
0: Weak<T>Implementations
Methods from Deref<Target = Weak<T>>
Sourcepub fn allocator(&self) -> &A
🔬This is a nightly-only experimental API. (allocator_api)
pub fn allocator(&self) -> &A
allocator_api)Returns a reference to the underlying allocator.
1.45.0 · Sourcepub fn as_ptr(&self) -> *const T
pub fn as_ptr(&self) -> *const T
Returns a raw pointer to the object T pointed to by this Weak<T>.
The pointer is valid only if there are some strong references. The pointer may be dangling,
unaligned or even null otherwise.
Examples
use std::sync::Arc;
use std::ptr;
let strong = Arc::new("hello".to_owned());
let weak = Arc::downgrade(&strong);
// Both point to the same object
assert!(ptr::eq(&*strong, weak.as_ptr()));
// The strong here keeps it alive, so we can still access the object.
assert_eq!("hello", unsafe { &*weak.as_ptr() });
drop(strong);
// But not any more. We can do weak.as_ptr(), but accessing the pointer would lead to
// undefined behavior.
// assert_eq!("hello", unsafe { &*weak.as_ptr() });1.4.0 · Sourcepub fn upgrade(&self) -> Option<Arc<T, A>>where
A: Clone,
pub fn upgrade(&self) -> Option<Arc<T, A>>where
A: Clone,
Attempts to upgrade the Weak pointer to an Arc, delaying
dropping of the inner value if successful.
Returns None if the inner value has since been dropped.
Examples
use std::sync::Arc;
let five = Arc::new(5);
let weak_five = Arc::downgrade(&five);
let strong_five: Option<Arc<_>> = weak_five.upgrade();
assert!(strong_five.is_some());
// Destroy all strong pointers.
drop(strong_five);
drop(five);
assert!(weak_five.upgrade().is_none());1.41.0 · Sourcepub fn strong_count(&self) -> usize
pub fn strong_count(&self) -> usize
Gets the number of strong (Arc) pointers pointing to this allocation.
If self was created using Weak::new, this will return 0.
1.41.0 · Sourcepub fn weak_count(&self) -> usize
pub fn weak_count(&self) -> usize
Gets an approximation of the number of Weak pointers pointing to this
allocation.
If self was created using Weak::new, or if there are no remaining
strong pointers, this will return 0.
Accuracy
Due to implementation details, the returned value can be off by 1 in
either direction when other threads are manipulating any Arcs or
Weaks pointing to the same allocation.
1.39.0 · Sourcepub fn ptr_eq(&self, other: &Weak<T, A>) -> bool
pub fn ptr_eq(&self, other: &Weak<T, A>) -> bool
Returns true if the two Weaks point to the same allocation similar to ptr::eq, or if
both don’t point to any allocation (because they were created with Weak::new()). However,
this function ignores the metadata of dyn Trait pointers.
Notes
Since this compares pointers it means that Weak::new() will equal each
other, even though they don’t point to any allocation.
Examples
use std::sync::Arc;
let first_rc = Arc::new(5);
let first = Arc::downgrade(&first_rc);
let second = Arc::downgrade(&first_rc);
assert!(first.ptr_eq(&second));
let third_rc = Arc::new(5);
let third = Arc::downgrade(&third_rc);
assert!(!first.ptr_eq(&third));Comparing Weak::new.
use std::sync::{Arc, Weak};
let first = Weak::new();
let second = Weak::new();
assert!(first.ptr_eq(&second));
let third_rc = Arc::new(());
let third = Arc::downgrade(&third_rc);
assert!(!first.ptr_eq(&third));Trait Implementations
impl<T> Eq for WeakEq<T>