pub fn on_blocked_changed(
child: impl IntoUiNode,
handler: Box<dyn FnMut(&bool) -> HandlerResult + Send>,
) -> UiNodeExpand description
Widget interactions where blocked or unblocked.
Note that blocked widgets may still be visually enabled, see Interactivity for more details.
See on_interactivity_changed for a more general interactivity event.
Route
This event property uses a direct route, that is, it cannot be intercepted in parent widgets.