pub fn on_interactivity_changed(
child: impl IntoUiNode,
handler: Box<dyn FnMut(&Interactivity) -> HandlerResult + Send>,
) -> UiNodeExpand description
P Widget interactivity changed.
Note that there are multiple specific events for interactivity changes, on_enabled, on_disabled, on_blocked and on_unblocked
are some of then.
Route
This event property uses a direct route, that is, it cannot be intercepted in parent widgets.