pub struct ParallelBuilder<B>(/* private fields */);Expand description
Represents a builder split from the main builder that can be used in parallel and then folded back onto the main builder.
Error
Logs an error on drop if it was not moved to the B::parallel_fold method.