pub fn on_ime(
child: impl IntoUiNode,
handler: Box<dyn FnMut(&ImeArgs) -> HandlerResult + Send>,
) -> UiNodeExpand description
P On Input Method Editor event.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.