pub fn on_pre_window_state_changed(
child: impl IntoUiNode,
handler: Box<dyn FnMut(&WindowChangedArgs) -> HandlerResult + Send>,
) -> UiNodeExpand description
P On window state changed.
This event notifies every time the user or the app changes the WindowVars::state.
Route
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the
$pn_ident
handlers.