pub fn on_window_moved(
child: impl IntoUiNode,
handler: Box<dyn FnMut(&WindowChangedArgs) -> HandlerResult + Send>,
) -> UiNodeExpand description
P On window position changed.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.