#[non_exhaustive]pub struct WindowRootExtenderArgs {
pub root: UiNode,
}Expand description
Arguments for WINDOWS_EXTENSIONS.register_root_extender.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.root: UiNodeThe window root content, extender must wrap this node with extension nodes or return it for no-op.