WidgetInfoImeArea

Trait WidgetInfoImeArea 

pub trait WidgetInfoImeArea {
    // Required method
    fn ime_area(&self) -> Option<Rect<Px, Px>>;
}
IME extension methods for WidgetInfo.

Required Methods

fn ime_area(&self) -> Option<Rect<Px, Px>>

IME exclusion area in the window space when this widget is focused.

The are is usually inside the widget inner bounds, representing the text caret or selection.

Implementors